<?php


namespace App\Filters\Patch\PaymentHistory;

use App\Filters\Core\BaseFilter;
use App\Filters\Patch\Traits\InvoiceAgentFilterTraits;
use App\Filters\Patch\Traits\InvoiceClientFilterTraits;
use App\Filters\Patch\Traits\PaymentMethodFilterTraits;
use App\Models\Patch\Traits\InvoiceIndividualAgentTrait;
use App\Models\Patch\Traits\InvoiceIndividualClientTrait;
use Illuminate\Database\Eloquent\Builder;

class PaymentHistoryFilter  extends BaseFilter
{
    use InvoiceClientFilterTraits,InvoiceAgentFilterTraits, PaymentMethodFilterTraits,InvoiceIndividualClientTrait,InvoiceIndividualAgentTrait;

    public function search($search = null)
    {
        return $this->builder->when($search, function (Builder $builder) use ($search) {
            $builder->whereHas('invoice', function (Builder $builder) use ($search) {
                $builder->where('invoice_number', 'LIKE', "%$search%");
            });
        });
    }

    public function date($date = null)
    {
        $date = json_decode(htmlspecialchars_decode($date), true);
        return $this->builder->when($date, function (Builder $builder) use ($date) {
            $builder->whereBetween(\DB::raw('DATE(received_on)'), array_values($date));
        });
    }

    public function amountRange($value = null)
    {
        $value = json_decode(htmlspecialchars_decode($value), true);
        return $this->builder->when($value, function (Builder $builder) use ($value) {
            $builder->whereBetween('amount', array_values($value));
        });

    }

}
