<?php


namespace App\Filters\Patch\Rewards;


use App\Filters\FilterBuilder;
use App\Filters\Patch\Traits\DateRangeFilter;
use App\Filters\Traits\UnitNameFilter;
use Illuminate\Database\Eloquent\Builder;
use Illuminate\Support\Facades\DB;

class RewardsFilter  extends FilterBuilder
{
    use  DateRangeFilter;

    public function search($search = null)
    {
        return $this->builder->when($search, function (Builder $builder) use ($search) {
            $builder->whereHas('agent', function (Builder $builder) use ($search) {
                $builder->where('first_name', 'LIKE', "%$search%")
                    ->orWhere('last_name', 'LIKE', "%{$search}%")
                    ->orWhereRaw(DB::raw('CONCAT(`first_name`, " ", `last_name`) LIKE ?'), ["%$search%"]);
            });
            $builder->orWhereHas('unit', function (Builder $builder) use ($search) {
                $builder->where('unit_name', 'LIKE', "%$search%");
                $builder->orWhereHas('property', function (Builder $builder) use ($search) {
                    $builder->where('property_name', 'LIKE', "%$search%")
                        ->orWhere('project_name', 'LIKE', "%$search%");
                });
            });
        });
    }

    public function paymentStatus($status){
        return $this->builder->when($status, function (Builder $builder) use ($status) {
            $builder->where('payment_status_id', '=', "$status");
        });
    }

    public function agents($ids = null)
    {
        $agents = explode(',', $ids);

        $this->builder->when($ids, function (Builder $query) use ($agents) {
            $query->whereHas('agent', function (Builder $query) use ($agents) {
                $query->whereIn('id', $agents);
            });
        });
    }
    public function properties($ids = null)
    {
        $properties = explode(',', $ids);

        $this->builder->when($ids, function (Builder $query) use ($properties) {
            $query->whereHas('property', function (Builder $query) use ($properties) {
                $query->whereIn('id', $properties);
            });
        });
    }
    public function units($ids = null)
    {
        $units = explode(',', $ids);

        $this->builder->when($ids, function (Builder $query) use ($units) {
            $query->whereHas('unit', function (Builder $query) use ($units) {
                $query->whereIn('id', $units);
            });
        });
    }
}
