<?php

namespace App\Http\Composer;

use App\Models\Core\Builder\Table\CustomTable;
use Illuminate\View\View;

class SidebarComposer
{
    public function compose(View $view)
    {

        $menu = [
            [
                'icon' => 'pie-chart',
                'name' => trans('custom.dashboard'),
                'url' => request()->root() . '/admin/dashboard',
                'permission' => auth()->user()->can('view_default'),
            ],

            [
                'id' => 'lead-modules',
                'icon' => 'command',
                'name' => 'Unit Leads',
                'permission' => authorize_any(['view_properties']),
                'subMenu' => [
                    [
                        'name' => 'Reserved Leads',
                        'url' => request()->root() . '/agent/leads/view',
                        'permission' => auth()->user()->can('view_properties'),
                    ],
                    [
                        'name' => "Unit Prospects",
                        'url' => request()->root() . '/agents/leads/prospects',
                        'permission' => auth()->user()->can('property_units_view'),
                    ],


                    [
                        'name' => "Offer Letter",
                        'url' => request()->root() . '/agents/leads/offer/letter',
                        'permission' => auth()->user()->can('view_properties'),
                    ],


                    [
                        'name' => "Sale Agreement",
                        'url' => request()->root() . '/agents/leads/sale/agreement',
                        'permission' => auth()->user()->can('property_units_view'),
                    ],


                    [
                        'name' => "Unsuccessful Leads",
                        'url' => request()->root() . '/agents/leads/unsuccessful',
                        'permission' => auth()->user()->can('property_units_view'),
                    ],

                ],
            ],

//            [
//                'icon' => 'command',
//                'name' => 'Leads',
//                'url' => request()->root() . '/agent/leads/view',
//                'permission' => auth()->user()->can('view_customers'),
//            ],

            [
                'icon' => 'layout',
                'name' => 'Companies',
                'url' => request()->root() . '/companies/list/view',
                'permission' => auth()->user()->can(['view_companies']),


            ],

            [
//                'id' => 'customer-modules',
                'icon' => 'users',
                'name' => 'Customers',
                'permission' => auth()->user()->can(['view_customers','view_properties']),
                'url' => request()->root() . '/customers/list/view',
//                'subMenu' => [
//                    [
//                        'name' => 'Customers',
//                        'url' => request()->root() . '/customers/list/view',
//                        'permission' => auth()->user()->can('view_properties'),
//                    ],
//
//                    [
//                        'name' => 'KYC Documents',
//                        'url' => request()->root() . '/customers/documents/kyc',
//                        'permission' => auth()->user()->can('view_properties'),
//                    ],
//                ]
            ],

            [
                'icon' => 'user-plus',
                'name' => 'Agents',
                'url' => request()->root() . '/agents/list/view',
                'permission' => authorize_any(['view_agents']),

            ],

            [
                'id' => 'property-modules',
                'icon' => 'bar-chart',
                'name' => 'Properties & Units',
                'permission' => authorize_any(['create_properties','view_properties','property_units_view']),
                'subMenu' => [
                    [
                        'name' => trans('custom.property'),
                        'url' => request()->root() . '/properties/list/view',
                        'permission' => auth()->user()->can('view_properties'),
                    ],

                    [
                        'name' => "Admin Units",
                        'url' => request()->root() . '/properties/admin/units',
                        'permission' => auth()->user()->can('property_units_import'),
                    ],

                    [
                        'name' => "Units for Sale",
                        'url' => request()->root() . '/properties/units/view',
                        'permission' => auth()->user()->can('property_units_view'),
                    ],

                    [
                        'name' => "Sold Units",
                        'url' => request()->root() . '/properties/units/sold/view',
                        'permission' => auth()->user()->can('property_units_view'),
                    ],

                ],
            ],


            [
                'id' => 'document-modules',
                'icon' => 'folder',
                'name' => 'Legal',
                'permission' => authorize_any(['process_offer_letter','process_sale_agreement']),
                'subMenu' => [

                    [
                        'name' => 'Process Offer Letter',
                        'url' => request()->root() . '/legal/process/offer/letter/view',
                        'permission' => auth()->user()->can('process_offer_letter'),
                    ],

                    [
                        'name' => 'Process Sale Agreement',
                        'url' => request()->root() . '/legal/process/sale/agreement/view',
                        'permission' => auth()->user()->can('process_sale_agreement'),
                    ],

                    [
                        'name' => 'Process Title Deeds',
                        'url' => request()->root() . '/legal/process/titles/view',
                        'permission' => auth()->user()->can('process_sale_agreement'),
                    ],

//                    [
//                        'name' => trans('custom.deeds'),
//                        'url' => request()->root() . '/titles',
//                        'permission' => auth()->user()->can('view_title_deeds'),
//                    ],
//
//                    [
//                        'name' => trans('custom.documents'),
//                        'url' => request()->root() . '/projects/lists/view',
//                        'permission' => auth()->user()->can('view_documents'),
//                    ],


                ],
            ],

//            [
//                'icon' => 'award',
//                'name' => 'Property Sales',
//                'url' => request()->root() . '/sales/list/view',
//                'permission' => auth()->user()->can('view_leads'),
//            ],

            [
                'icon' => 'file-text',
                'id' => 'invoices',
                'name' => trans('custom.invoice'),
                'permission' => authorize_any(['view_invoices']),
                'subMenu' => [
                    [
                        'name' => trans('default.invoices'),
                        'url' => request()->root() . '/invoices/list/view',
                        'permission' => auth()->user()->can('view_invoices'),
                    ],
                    [
                        'name' => trans('default.recurring_invoices'),
                        'url' => request()->root() . '/recurring/invoice/list/view',
                        'permission' => auth()->user()->can('view_invoices'),
                    ],
                ]
            ],

//            [
//                'icon' => 'briefcase',
//                'name' => trans('custom.payments'),
//                'url' => request()->root() . '/payments/list/view',
//                'permission' => auth()->user()->can('view_payments'),
//            ],

            [
                'icon' => 'briefcase',
                'id' => 'finance-module',
                'name' => 'Finance',
                'permission' => authorize_any(['view_payments']),
                'subMenu' => [


                    [
                        'name' => 'Confirm OL Payments',
                        'url' => request()->root() . '/finance/confirm/offer/letter/view',
                        'permission' => auth()->user()->can('view_payments'),
                    ],

                    [
                        'name' => 'Confirm SA Payments',
                        'url' => request()->root() . '/finance/confirm/sale/agreement/view',
                        'permission' => auth()->user()->can('view_payments'),
                    ],

                    [
                        'name' => 'Confirm RU Payments',
                        'url' => request()->root() . '/payments/reserved/list/view',
                        'permission' => auth()->user()->can('view_payments'),
                    ],

                    [
                        'name' => 'Recurring Payments',
                        'url' => request()->root() . '/finance/payments/confirm/view',
                        'permission' => auth()->user()->can('view_payments'),
                    ],

                    [
                        'name' => 'Unit  Payments',
                        'url' => request()->root() . '/payments/list/view',
                        'permission' => auth()->user()->can('view_payments'),
                    ],





                ]
            ],

            [
                'icon' => 'shopping-cart',
                'id' => 'sale-rewards',
                'name' => 'Sale Rewards',
                'permission' => authorize_any(['view_commission']),
                'subMenu' => [
                    [
                        'name' => 'Agent Commissions',
                        'url' => request()->root() . '/rewards/commission/list/view',
                        'permission' => auth()->user()->can('view_commission'),
                    ]
                ]
            ],

            [
                'name' => trans('default.reports'),
                'id' => 'reports',
                'icon' => 'bar-chart-2',
                'permission' => authorize_any([
                    'payment_summary_reports',
                    'client_statement_report_reports',
                    'invoice_report_reports',
                    'general-summary_reports'
                ]),
                'subMenu' => [

//                    [
//                        'name' => 'General Summary Report',
//                        'url' => request()->root() . '/general-summary',
//                        'permission' => auth()->user()->can('general-summary_reports'),
//                    ],
                    [
                        'name' => trans('default.payments_summary'),
                        'url' => request()->root() . '/payment-summary',
                        'permission' => auth()->user()->can('payment_summary_reports'),
                    ],
                    [
                        'name' => trans('default.client_statement'),
                        'url' => request()->root() . '/client-statement',
                        'permission' => auth()->user()->can('client_statement_report_reports'),
                    ],
                    [
                        'name' => trans('default.invoice_report'),
                        'url' => request()->root() . '/invoice-report',
                        'permission' => auth()->user()->can('invoice_report_reports'),
                    ],
                ],
            ],

            [
                'icon' => 'user-check',
                'name' => trans('custom.user_and_roles'),
                'url' => request()->root() . '/users-and-roles',
                'permission' => auth()->user()->can('view_titles'),
            ],

            [
                'icon' => 'layers',
                'name' => trans('custom.property_settings'),
                'url' => request()->root() . '/property-setting',
                'permission' => authorize_any(['view_settings', 'update_settings']),

            ],


            [
                'icon' => 'settings',
                'name' => trans('custom.settings'),
                'url' => request()->root() . '/app-setting',
                'permission' => authorize_any(
                    [
                        'view_settings', 'update_settings',
                        'view_delivery_settings',
                        'update_delivery_settings',
                        'view_sms_settings', 'update_sms_settings',
                        'view_recaptcha_settings',
                        'view_payment_method',
                        'update_payment_method',
                        'delete_payment_method',
                        'view_notification_settings', 'update_notification_settings', 'update_notification_templates',
                        'view_notification_templates',
                    ]
                ),
            ],
        ];


        $view->with(['data' => $menu]);
    }
}
