<?php


namespace App\Http\Controllers\App\AgentLeed;


use App\Filters\Patch\Agent\ProspectFilter;
use App\Http\Controllers\Controller;
use App\Models\Prospect;
use App\Services\Patch\Liason\ProspectService;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;

class ProspectController  extends Controller
{

    public function __construct(ProspectService $service, ProspectFilter $filter)
    {
        $this->service = $service;
        $this->filter = $filter;


    }

    public function index()
    {
        try{
            $user = Auth::user();

            $query = Prospect::with([
                'unit:id,unit_name,sale_amount,square_foot,unit_floor',
                'status:id,name,class',
                'payment_status:id,name,class',
                'property:id,project_name',
                'user:id,first_name,last_name'
            ])->where('status_id',18)->filters($this->filter);

            if (!$user->isAppAdmin()) {
                $query->where('user_id', $user->id);
            }

//        return $query->orderBy('id', request()->get('orderBy'))
//            ->paginate(request('per_page', 10));

            // Fetch the paginated result
            $results = $query->orderBy('id', request()->get('orderBy'))
                ->paginate(request('per_page', 10));

            // Map the result to add sale_amount at the top level
            $results->getCollection()->transform(function ($item) {
                $item->sale_amount = $item->unit->sale_amount; // Add sale_amount at the top level
                return $item;
            });

            return $results;
        }
        catch (\Exception $exception){
            echo $exception->getMessage();
        }
    }


    public function show($id)
    {

        return $this->service->with([
            'unit',
            'status:id,name,class',
            'payment_status:id,name,class',
            'property',
        ])->find($id);

    }

    public function store(Request $request)
    {

        $requestData = $request->only(['user_id', 'unit_id', 'status_id', 'payment_status_id', 'client_name', 'email', 'phone',]);
        $requestData['user_id'] = Auth::id();
        $requestData['status_id'] = 18;
        $this->service
            ->setAttributes($requestData)
            ->save();
        return created_responses('crud_response');

    }


    public function update(Prospect $unit,$id)
    {

        $unit = $this->service->find($id);

        $this->service->where('id', $id)->update(\request()->only('status_id'));;

        return updated_responses('crud_response');
    }

    public function destroy(Prospect $prospect)
    {
        $this->service
            ->setModel($prospect)
            ->delete();
        return deleted_responses('crud_response');
    }


}