<?php


namespace App\Http\Controllers\App\Company;


use App\Filters\Patch\Company\CompanyFilter;
use App\Http\Controllers\Controller;
use App\Models\Company;
use App\Services\Core\Company\CompanyService;
use Illuminate\Http\Request;

class CompanyController  extends Controller
{

    public function __construct(CompanyService $service, CompanyFilter $filter)
    {
        $this->service = $service;
        $this->filter = $filter;
    }


    public function index()
    {
        return $this->service
            ->with([
                'country:id,name',
                'user' => function ($query) {
                    $query->with('profilePicture', 'status:id,name,class', 'profile:id,user_id,address,contact');
                }])
            ->filters($this->filter)
            ->orderBy('id', request()->get('orderBy'))
            ->paginate(request('per_page', 10));

    }


    public function show($id)
    {
        return $this->service->find($id);

    }

    public function store(Request $request)
    {
        $password = $this->service->randomPassword();

        $this->service
            ->setValidation()
            ->setUserValidation()
            ->saveUser($password)
            ->roleAssign()
            ->companyStore()
            ->profileStore()
            ->companyInvitationMail($password);
        return created_responses('companies');
    }

    public function update(Request $request, Company $company)
    {
        $this->service
            ->setModel($company)
            ->setUpdateValidation()
            ->setUserValidation()
            ->updateUser()
            ->setAttributes($request->all())
            ->update()
            ->updateProfile() ;

        return updated_responses('companies');
    }


    public function destroy(Company $company)
    {
        $this->service
            ->setModel($company)
            ->delete();
        return deleted_responses('companies');
    }

}