<?php

namespace App\Http\Controllers\App\Customer;
use App\Exports\ClientExport;
use App\Exports\ClientImport;
use App\Filters\Patch\Customer\ClientFilter;
use App\Http\Controllers\Controller;
use App\Exceptions\GeneralException;
use App\Models\AgentLead;
use App\Models\Core\Auth\User;
use App\Models\Customer;
use App\Models\Invoice;
use App\Models\UnitBooking;
use App\Services\Core\Customer\CustomerService;
use App\Services\Patch\Liason\TitleDeedService;
use Illuminate\Http\Request;
use Exception;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Validator;
use Illuminate\Validation\Rule;
use Maatwebsite\Excel\Facades\Excel;



class CustomerController extends Controller
{
    public function __construct(CustomerService $service,ClientFilter $filter)
    {
        $this->service = $service;
        $this->filter = $filter;
    }

    public function index()
    {
        $user = Auth::user();

        $query = Customer::with([
            'country:id,name',
            'user' => function ($query) {
                $query->with('profilePicture', 'status:id,name,class', 'profile:id,user_id,address,contact');
            }
        ])->filters($this->filter);

        if (!$user || !$user->isAppAdmin()) {
            $query->where('created_by', $user->id ?? 0); // Handle null user
        }

// Sanitize inputs
        $allowedColumns = ['id', 'name', 'created_at'];
        $orderBy = in_array(request()->get('orderBy'), $allowedColumns) ? request()->get('orderBy') : 'id';
        $perPage = request()->get('per_page', 10);

        return $query->orderBy($orderBy)
            ->paginate($perPage);



//        $query = Customer::with([
//            'country:id,name',
//            'user' => function ($query) {
//                $query->with('profilePicture', 'status:id,name,class', 'profile:id,user_id,address,contact');
//            }
//        ])->filters($this->filter);
//
//        if (!$user->isAppAdmin()) {
//            $query->where('created_by', $user->id);
//        }
//
//        return $query->orderBy('id', request()->get('orderBy'))
//            ->paginate(request('per_page', 10));

    }


    public function store(Request $request)
    {
//        $password = $this->service->randomPassword();
//        $this->service
//            ->setValidation()
//            ->setAttributes($request->all()) // Set the modified request data
//            ->setUserValidation()
//            ->saveUser($password)
//            ->roleAssign()
//            ->clientStore()
//            ->profileStore()
//            ->clientInvitationMail($password);
//
//
//          $this->service->when($request->has('attachment'), fn(CustomerService $service) => $service->saveAttachment($request->attachment));
//        return created_responses('clients');

        try{
            $requestData = $request->all();
            $requestData['created_by'] = Auth::id();
//        $requestData['created_by'] = 24;
            $password = $this->service->randomPassword();

            $this->service
                ->setValidation()
                ->setUserValidation()
                ->setAttributes($requestData) // Set the modified request data
                ->saveUser($password)
                ->roleAssign()
                ->clientStore()
                ->profileStore()
                ->clientInvitationMail($password);

//        $this->service->when($request->has('attachment'), fn(CustomerService $service) => $service->saveAttachment($request->attachment));

            return created_responses('clients');
        }
        catch (Exception $exception){
            return $exception->getMessage();
        }



    }


    public function show($id)
    {
       // return $this->service->find($id);

        return $this->service->with([
            'country:id,name',
            'user' => function ($query) {
                $query->with('profilePicture', 'profile:id,user_id,address,contact');
            }])->find($id);

    }

//
//    public function update(Request $request, Customer $client)
//    {
//        $this->service
//            ->setModel($client)
//            ->setUpdateValidation()
//            ->setUserValidation()
//            ->updateUser()
//            ->setAttributes($request->all())
//            ->update()
//            ->updateProfile();
//
//        return updated_responses('clients');
//    }

    public function update(Request $request, Customer $customer)
    {

        // Validation rules
        $rules = [
            'full_name' => 'required|string|max:255',
            'email' => 'required|email|max:255|unique:users,email,' . $request->user_id,
            'user_id' => 'required|exists:users,id',
        ];

        $validator = Validator::make($request->all(), $rules);

        if ($validator->fails()) {
            return response()->json(['errors' => $validator->errors()], 422);
        }

        // Find the client
        $client = Customer::findOrFail($request->input('id'));

        // Find the user
        $user = User::findOrFail($request->input('user_id'));

        // Begin transaction

        DB::beginTransaction();

        try {
            // Update the user
            $user->update([
                'first_name' => $request->input('first_name'),
                'last_name' => $request->input('last_name'),
                'email' => $request->input('email'),
            ]);

            // Update the client
            $client->update([
                'full_name' => $request->input('full_name'),
                'country_id' => $request->input('country_id'),
                'address' => $request->input('address'),
                'phone' => $request->input('phone'),
                'id_number' => $request->input('id_number'),
                'kra_pin' => $request->input('kra_pin'),
                'dob' => $request->input('dob'),
                'location_address' => $request->input('location_address'),
                'gender' => $request->input('gender'),
                'kin_name' => $request->input('kin_name'),
                'kin_id' => $request->input('kin_id'),
                'kin_kra_pin' => $request->input('kin_kra_pin'),
                'kin_email' => $request->input('kin_email'),
                'kin_phone' => $request->input('kin_phone'),
                'kin_box_address' => $request->input('kin_box_address'),
                'kin_location_address' => $request->input('kin_location_address'),
                'kin_gender' => $request->input('kin_gender'),
                'bank_name' => $request->input('bank_name'),
                'bank_branch' => $request->input('bank_branch'),
                'account_name' => $request->input('account_name'),
                'account_no' => $request->input('account_no'),
                'currency' => $request->input('currency'),
                'swift_code' => $request->input('swift_code'),
            ]);

            // Commit transaction
            DB::commit();

            return updated_responses('clients');
        } catch (\Exception $e) {
            // Rollback transaction
            DB::rollBack();

            return updated_responses('clients');
        }

        return updated_responses('clients');
    }

    public function destroy(Customer $client)
    {
        $invoiceExist = $client->load(['user' => function ($query) {
            $query->withCount('invoices');
        }]);

        if (optional($invoiceExist->user)->invoices_count > 0)
            throw new GeneralException(trans('default.this_client_has_an_invoice_record'));

        $this->service
            ->setModel($client)
            ->userDelete()
            ->delete();

        return deleted_responses('clients');
    }


    public function clientInvoices($id): \Illuminate\Contracts\Pagination\LengthAwarePaginator
    {
        $userId = $this->service->find($id)->user_id;
        return Invoice::with(['status', 'client'])
            ->where('client_id', $userId)
            ->orderBy('id', request()->get('orderBy'))
            ->paginate(request('per_page', 10));
    }


    public function clientUnits($id): \Illuminate\Contracts\Pagination\LengthAwarePaginator
    {
        $userId = $this->service->find($id)->user_id;
        return UnitBooking::with(['plan','unit','customer'])
            ->where('customer_id', $userId)
            ->orderBy('id', request()->get('orderBy'))
            ->paginate(request('per_page', 10));
    }


    public function exportClients()
    {
        return Excel::download(new ClientExport(), 'clients.csv', \Maatwebsite\Excel\Excel::CSV);
    }

    public function importClients(Request $request)
    {
        $request->validate([
            'file' => 'required|mimes:csv,txt',
        ]);
        $file = $request->file('file');
        return   Excel::import(new ClientImport($this->service), $file);
    }

}
