<?php

namespace App\Http\Controllers\App\Dashboard;

use App\Http\Controllers\Controller;
use App\Services\App\Dashboard\DashboardService;
use Illuminate\Http\Request;

class DashboardController extends Controller
{
    public function __construct(DashboardService $service)
    {
        $this->service = $service;
    }

    public function card(Request $request): array
    {
        try {
            $propertyIds = $request->input('property_id');

            // Fetching data using the service methods
            $totalAgent = $this->service->totalAgent();
            $totalClient = $this->service->totalClient();
            $totalUnitsBooked = $this->service->totalUnitsBooked($propertyIds);
            $totalProperties = $this->service->totalProperties($propertyIds);
            $totalLeads = $this->service->totalReservedLeeds($propertyIds);
            $totalProspects = $this->service->totalProspects($propertyIds);
            $offerLetter = $this->service->offerLetter($propertyIds, $this->service->documentStatus['document_pending_upload']);
            $saleLetter = $this->service->saleAgreement($propertyIds);
            $totalInvoice = $this->service->invoiceCount(null, $propertyIds);
            $totalPayment = $this->service->paymentSummation('received_amount', $propertyIds);
            $totalAmount = $this->service->paymentSummation('total', $propertyIds);
            $totalDueAmount = $this->service->paymentSummation('due_amount', $propertyIds);
            $totalProcessingFee = $this->service->paymentSummation('processing_fee', $propertyIds);
            $totalProduct = $this->service->totalProperty($propertyIds);
            $totalUnit = $this->service->totalUnits($propertyIds);
            $totalPaidInvoice = $this->service->invoiceCount($this->service->status['status_paid'], $propertyIds);
            $unpaidInvoices = $this->service->invoiceCount($this->service->status['status_unpaid'], $propertyIds);
            $partiallyPaidInvoices = $this->service->invoiceCount($this->service->status['status_partially_paid'], $propertyIds);
            $overdueInvoices = $this->service->invoiceCount($this->service->status['status_overdue'], $propertyIds);

            // Determine user permissions for showing data
            $canShowAllData = auth()->user()->can('show_all_data');

            // Return the data as an array
            return [
                'totalClient' => $canShowAllData ? $totalClient : 0,
                'totalAgent' => $canShowAllData ? $totalAgent : 0,
                'totalInvoice' => $totalInvoice,
                'totalPayment' => $totalPayment,
                'totalAmount' => $totalAmount,
                'totalDueAmount' => $totalDueAmount,
                'totalUnit' => $totalUnit,
                'totalProduct' => $totalProduct,
                'totalProcessingFee' => $totalProcessingFee,
                'totalPaidInvoice' => $totalPaidInvoice,
                'unpaidInvoices' => $unpaidInvoices,
                'partiallyPaidInvoices' => $partiallyPaidInvoices,
                'overdueInvoices' => $overdueInvoices,
                'totalUnitsBooked' => $totalUnitsBooked,
                'totalProperties' => $totalProperties,
                'totalLeads' => $totalLeads,
                'totalProspects' => $totalProspects,
                'offerLetter' => $offerLetter,
                'saleLetter' => $saleLetter,
                'filteredProjects' => $propertyIds,
            ];
        } catch (\Exception $e) {
            // Handle the exception (log the error or return an error response)
            Log::error('Error fetching dashboard data: ' . $e->getMessage());

            // Return a custom error message
            return [
                'error' => 'An error occurred while fetching the data. Please try again later.'.$e->getMessage()
            ];
        }
    }


    public function paymentOverview(Request $request): array
    {
            $propertyIds = $request->input('property_id');
            $payments = $this->service->paymentOverView($propertyIds);

            $paymentChat = [];

            foreach ($payments as $payment) {
                $paymentChat[trans('default.received_amount')] = $payment->received_amount;
                $paymentChat[trans('default.due_amount')] = $payment->due_amount;
            }

            return ['payment_overview' => $paymentChat];
    }

    public function yearlyOverview(Request $request): array
    {
            $propertyIds = $request->input('property_id');
            $monthlyIncome = $this->service->monthlyIncome($propertyIds);
            return $this->service->manipulateChart($monthlyIncome);


    }

}
