<?php


namespace App\Http\Controllers\App\Documents\Legal;


use App\Filters\Patch\TitleDeed\TitleDeedFilter;
use App\Http\Controllers\Controller;
use App\Mail\Patch\SaleAgreementDocumentMail;
use App\Models\Core\Auth\User;
use App\Models\Customer;
use App\Models\LegalDocument;
use App\Models\UnitBooking;
use App\Services\Patch\Liason\OfferLetterDocumentService;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Mail;


class OfferLetterDocumentUploadController  extends Controller
{
    public function __construct(OfferLetterDocumentService $service, TitleDeedFilter $filter)
    {
        $this->service = $service;
        $this->filter = $filter;

    }


    public function index(Request $request)
    {
        if ($request->has('unit_id')) {
            return $this->service
                ->filters($this->filter)
                ->where('unit_id', $request->unit_id) // Filter by unit_id
                ->with([
                    'attachment',
                    'user' => function ($query) {
                        $query->with('profilePicture', 'status:id,name,class', 'profile:id,user_id,address,contact');
                    }
                ])
                ->orderByDesc('id')
                ->paginate($request->get('per_page', 15));
        }

        // If 'unit_id' is not provided, return an error response
        return response()->json([
            'message' => 'unit_id is required'
        ], 400);
    }

    public function store(Request $request)
    {
        try {
            DB::beginTransaction(); // Start transaction
            $agentId = $request->user_id;

            $request['user_id'] = Auth::id();

            // Validate and save
            $this->service
                ->checkValidation()
                ->setAttributes($request->except('attachment'))
                ->save();

            // Handle attachment
            if ($request->has('attachment')) {
                $this->service->saveAttachment($request->attachment);
            }

            // Fetch client and agent emails
            $client = Customer::where('user_id', $request->customer_id)->first();
            $agent = User::where('id', $agentId)->first();

            $client_email = $client->email ?? null;
            $agent_email = $agent->email ?? null;

            if ($client_email || $agent_email) {
                // Prepare and send mail
                $email = Mail::to($client_email);
                if ($agent_email) {
                    $email->cc($agent_email);
                }
                $email->send(new SaleAgreementDocumentMail($request->attachment, "An Offer Letter"));
            }

            // Update document status
            $unit = UnitBooking::where('unit_id', $request->unit_id)->firstOrFail();
            $unit->document_status_id = 20;
            $unit->save();

            DB::commit(); // Commit transaction

            return created_responses('crud_response');

        } catch (\Exception $e) {
            DB::rollBack(); // Roll back on error
            report($e); // Log error for debugging
            return response()->json(['error' => $e->getMessage()], 500);
        }
    }

    public function update(Request $request, LegalDocument $expense)
    {
        $this->service
            ->setModel($expense)
            ->checkValidation()
            ->setAttributes($request->except('attachment'))
            ->save();

        $this->service->when($request->has('attachment'), fn(OfferLetterDocumentService $service) => $service->saveAttachment($request->attachment));

        return updated_responses('crud_response');
    }

    public function destroy(LegalDocument $lg)
    {
        $this->service
            ->setModel($lg)
            ->deleteAttachment()
            ->deleteAttachmentData()
            ->delete();
        return deleted_responses('crud_response');
    }

}