<?php


namespace App\Http\Controllers\App\Payment;

use App\Mail\Patch\LegalReminderNotification;
use Illuminate\Support\Facades\DB;
use App\Filters\Patch\PaymentHistory\PaymentHistoryFilter;
use App\Http\Controllers\Controller;
use App\Mail\Patch\PaymentNotification;
use App\Models\Commission;
use App\Models\Customer;
use App\Models\Payment;
use App\Models\Property;
use App\Models\UnitBooking;
use App\Project;
use App\Services\Patch\Liason\PaymentHistoryService;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Mail;
use Lcobucci\JWT\Exception;

class ConfirmPaymentController  extends Controller
{

    public function __construct(PaymentHistoryService $service, PaymentHistoryFilter $filter)
    {
        $this->service = $service;
        $this->filter = $filter;
    }

    public function index()
    {
        return $this->service
            ->with([
                    'paymentMethod:id,name',
                    'payment_status:id,name,class',

                    'invoice' => function ($query) {
                        $query->select('id', 'invoice_number', 'client_id')
                            ->with('client:id,first_name,last_name');
                    }]
            )->where('payment_status_id',16)
            ->filters($this->filter)
            ->orderBy('id', request()->get('orderBy'))
            ->paginate(request('per_page'));
    }


    public function store(Request $request)
    {
        $payment = $this->service
            ->setValidation()
            ->dueAmountUpdate()
            ->setAttributes($request->all())
            ->save();

        $invoiceInfo = $payment->load('invoice')->invoice;
//        $this->service->commissionAgent();

        $this->service
            ->setAttribute('file_path', 'public/pdf/invoice_' . $invoiceInfo->id . '.pdf')
            ->pdfGenerate($invoiceInfo);

//        InvoiceAttachmentJob::dispatch($invoiceInfo)->onQueue('high');
        return created_responses('payments');

    }


    public function show($id)
    {
        return $this->service->find($id);


    }

//    public function update(Payment $payment_history ,$id)
//    {
////        $this->service
////            ->setModel($payment_history)
////            ->setValidation()
////            ->adjustDueAmount()
////            ->setAttributes($request->all())
////            ->update();
////        return updated_responses('payments');
//
//
//        try{
//            $payment_history = $this->service->find($id);
//
//            if ($payment_history) {
//                // Update payment status
//                $this->service->where('id', $id)->update(\request()->only('payment_status_id'));
//
//                $invoiceId = $payment_history->invoice_id;
//
//                $bookingModel = UnitBooking::where('invoice_id', $invoiceId)->with('unit')->first();
//                if ($bookingModel) {
//                    // Get customer email
//                    $customer = Customer::where('user_id', $bookingModel->customer_id)->first();
//                    if ($customer) {
//                        $email = $customer->email;
//                        // Mail::to($email)->send(new PaymentNotification($payment_history));
//                    }
//
//                    // Check commission logic
//                    $property = Property::where('id', $bookingModel->unit['property_id'])->first();
//                    if ($property && $property->allow_commission == 1) {
//                        $targetAmountForSales = 0.1 * (double) $bookingModel->unit['sale_amount'];
//                        if ($bookingModel->amount >= $targetAmountForSales) {
//                            // Check if commission already exists
//                            $commission = Commission::where('unit_id', $bookingModel->unit_id)->first();
//                            if (!$commission) {
//                                $amount = $property->commission / 100 * (double) $bookingModel->unit['sale_amount'];
//                                $commission = new Commission();
//                                $commission->property_id = $bookingModel->unit['property_id'];
//                                $commission->unit_id = $bookingModel->unit['id'];
//                                $commission->commission_amount = $amount;
//                                $commission->company_share_amount = $amount;
//                                $commission->invoice_id = $bookingModel->invoice_id;
//                                $commission->save();
//                            }
//                        }
//                    }
//                }
//            }
//
//            //check if the amount exceeds 10%
//            //if so check if commission is registered
//            //compute commission
//
//            return updated_responses('crud_response');
//        }
//        catch (Exception $exception){
//            echo $exception->getMessage();
//        }
//
//
//
//
//    }



    public function update(Payment $payment_history, $id)
    {
        try {
            // Variable to hold email and notification data
            $email = null;
            $paymentHistorySnapshot = null;
            $sendLegalEmail = false;
            $documentType = '';
            $bookingModel= null;

            // Start the transaction
            DB::beginTransaction();

            $payment_history = $this->service->find($id);

            if ($payment_history) {
                // Update payment status
                $this->service->where('id', $id)->update(\request()->only('payment_status_id'));

                $invoiceId = $payment_history->invoice_id;

                $bookingModel = UnitBooking::where('invoice_id', $invoiceId)->with('unit')->first();
                if ($bookingModel) {
                    // Prepare customer email
                    $customer = Customer::where('user_id', $bookingModel->customer_id)->first();
                    if ($customer) {
                        $email = $customer->email;
                        $paymentHistorySnapshot = $payment_history; // Save for later email sending
                    }

                    // Check commission logic
                    $property = Property::where('id', $bookingModel->unit['property_id'])->first();
                    if ($property && $property->allow_commission == 1) {
                        //should be more or equal to 10%
                        $targetAmountForSales = 0.1 * (double)$bookingModel->unit['sale_amount'];
                        if ($bookingModel->amount >= $targetAmountForSales) {
                            // Check if commission already exists
                            $commission = Commission::where('unit_id', $bookingModel->unit_id)->first();
                            if (!$commission) {
                               $amount = $property->commission / 100 * (double)$bookingModel->unit['sale_amount'];
                                $commission = new Commission();
                                $commission->property_id = $bookingModel->unit['property_id'];
                                $commission->unit_id = $bookingModel->unit['id'];
                                $commission->commission_amount = $amount;
                                $commission->company_share_amount = $amount;
                                $commission->invoice_id = $bookingModel->invoice_id;
                                $commission->agent_id = $bookingModel->user_id;
                                $commission->payment_status_id = 30; //pending
                                $commission->save();
                            }
                        }
                    }

                    //check what stage the amount is offer letter 10%, sale agreement 0.25%,
                    // title deed 100% to send notification

                    $targetOfferLetter = 0.1 * (double)$bookingModel->unit['sale_amount'];
                    $targetSaleAgreement = 0.25 * (double)$bookingModel->unit['sale_amount'];
                    $titleDeed = (double)$bookingModel->unit['sale_amount'];

                    //if upload is pending
                    if ($bookingModel->document_status_id == 23){
                        //reminder to prepare offer letter
                        if ($bookingModel->amount >= $targetOfferLetter && $bookingModel->amount < $targetSaleAgreement) {
                            $sendLegalEmail = true;
                            $documentType = 'Offer Letter';
                        }
                        else
                        if ($bookingModel->amount >= $targetSaleAgreement && $bookingModel->amount != $titleDeed) {
                            $sendLegalEmail = true;
                            $documentType = 'Sale Agreement';
                        }
                        else if ($bookingModel->amount >= $titleDeed){
                            $sendLegalEmail = true;
                            $documentType = "Title Deed";
                        }
                    }


                }
            }

            // Commit the transaction
            DB::commit();

            // Send email after transaction is committed
            if ($email && $paymentHistorySnapshot) {
                Mail::to($email)->send(new PaymentNotification($paymentHistorySnapshot));
            }

            if ($sendLegalEmail){
                $legalEmail = env('LEGAL_REMINDER_EMAIL', 'legal@patchafrica.net');
                Mail::to($legalEmail)->send(new LegalReminderNotification($bookingModel, $documentType));
            }

            return updated_responses('crud_response');
        } catch (Exception $exception) {
            // Rollback the transaction if an error occurs
            DB::rollBack();
            // Log the exception or handle it as required
            echo $exception->getMessage();
        }
    }

    public function destroy(Payment $payment_history)
    {
        $this->service
            ->setModel($payment_history)
            ->delete();
        return deleted_responses('payments');

    }

}