<?php

namespace App\Http\Controllers\App\Payment;
use App\Filters\Patch\PaymentHistory\PaymentHistoryFilter;
use App\Http\Controllers\Controller;

use App\Jobs\InvoiceAttachmentJob;
use App\Models\Payment;
use App\Models\UnitBooking;
use App\Services\Patch\Liason\PaymentHistoryService;
use Illuminate\Http\Request;

class PaymentsController extends Controller
{

    public function __construct(PaymentHistoryService $service, PaymentHistoryFilter $filter)
    {
        $this->service = $service;
        $this->filter = $filter;
    }

    public function index()
    {
        return $this->service
            ->with([
                'paymentMethod:id,name',
                    'payment_status:id,name,class',
                    'invoice' => function ($query) {
                    $query->select('id', 'invoice_number', 'client_id')
                        ->with('client:id,first_name,last_name');
                }]
            )->where('payment_status_id',15)
            ->filters($this->filter)
            ->orderBy('id', request()->get('orderBy'))
            ->paginate(request('per_page'));
    }

    public function store(Request $request)
    {
        $payment = $this->service
            ->setValidation()
            ->dueAmountUpdate()
            ->setAttributes($request->all())
            ->save();

        $invoiceInfo = $payment->load('invoice')->invoice;
//        $this->service->commissionAgent();

        $invoiceId = $request->input('invoice_id');

        $invoice = UnitBooking::where('invoice_id', $invoiceId)->first();

        if ($invoice) {
            // Add the current amount to the existing one
            $newAmount = $request->input('amount');
            $invoice->amount += $newAmount;

            // Save the updated amount
            $invoice->save();
        }

        $this->service
            ->setAttribute('file_path', 'public/pdf/invoice_' . $invoiceInfo->id . '.pdf')
            ->pdfGenerate($invoiceInfo);

//        InvoiceAttachmentJob::dispatch($invoiceInfo)->onQueue('high');
        return created_responses('payments');

    }


    public function show($id)
    {
        return $this->service->find($id);


    }

    public function update(Request $request, Payment $payment_history)
    {
        $this->service
            ->setModel($payment_history)
            ->setValidation()
            ->adjustDueAmount()
            ->setAttributes($request->all())
            ->update();
        return updated_responses('payments');

    }


    public function destroy(Payment $payment_history)
    {
        $this->service
            ->setModel($payment_history)
            ->delete();
        return deleted_responses('payments');

    }
}
