<?php


namespace App\Http\Controllers\App\Properties;


use App\Filters\Patch\Document\DocumentFilter;
use App\Http\Controllers\Controller;
use App\Models\Document;
use App\Services\Patch\Liason\DocumentService;
use Illuminate\Http\Request;

class ProjectDocumentsController  extends Controller
{

    public function __construct(DocumentService $service, DocumentFilter $filter)
    {
        $this->service = $service;
        $this->filter = $filter;

    }

    public function index()
    {
        return $this->service
            ->filters($this->filter)
            ->with(['attachment'])
            ->orderByDesc('id')
            ->paginate(\request('per_page', 15));
    }

    public function show($id)
    {
        return $this->service
            ->with(['attachment'])
            ->find($id);

    }

    public function store(Request $request)
    {
        $this->service
            ->checkValidation()
            ->setAttributes($request->except('attachment'))
            ->save();

        $this->service->when($request->has('attachment'), fn(DocumentService $service) => $service->saveAttachment($request->attachment));

        return created_responses('documents');

    }

    public function update(Request $request, $id)
    {
        $document = Document::findOrFail($id);
        $this->service
            ->setModel($document)
            ->checkValidation()
            ->setAttributes($request->only(
                'name',
                'category'))
            ->update();

        $this->service->when($request->has('attachment'), fn(DocumentService $service) => $service->saveAttachment($request->attachment));

        return updated_responses('documents');
    }

    public function destroy($id)
    {
        $document = Document::findOrFail($id);
        $this->service
            ->setModel($document)
            ->deleteAttachment()
            ->deleteAttachmentData()
            ->delete();

        return deleted_responses('documents');
    }


}