<?php

namespace App\Http\Controllers\App\Properties;

use App\Filters\Patch\Property\PatchPropertyFilter;
use App\Http\Controllers\Controller;
use App\Models\Core\Setting\Setting;
use App\Models\Invoice;
use App\Models\Property;
use App\Models\Unit;
use App\Services\Patch\Liason\PatchPropertyService;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;


class PropertyController extends Controller
{

    public function __construct(PatchPropertyService $service, PatchPropertyFilter $filter)
    {
        $this->service = $service;
        $this->filter = $filter;
    }

    public function index()
    {
        if (\Request::exists('all')) {
            return $this->service->select('id', 'project_name', 'unit_no')->get();
        }
        $orderBy = request()->get('orderBy', 'asc'); // Default to 'asc' if no orderBy parameter is provided

        if (!in_array($orderBy, ['asc', 'desc'])) {
            $orderBy = 'asc'; // Set to default 'asc' if provided orderBy value is invalid
        }
        return $this->service
            ->with('file')
            ->filters($this->filter)
            ->orderBy('id', $orderBy)
            ->paginate(request('per_page', 10));

    }


    public function store(Request $request)
    {
        $this->service
            ->setValidation()
            ->setAttributes($request->all())
            ->save();
        $this->service->when($request->has('image'), fn(PatchPropertyService $service) => $service->image($request->image));

        return created_responses('products');


    }


    public function show($id)
    {
        return $this->service->with('file')->find($id);

    }


    public function update(Request $request, Property $property)
    {
        $this->service
            ->setModel($property)
            ->setValidation()
            ->setAttributes($request->all())
            ->update();
//        $this->service->when($request->has('image'), fn(PatchPropertyService $service) => $service->image($request->image));

        return updated_responses('properties');
    }


    public function destroy(Property $property)
    {

        $this->service
            ->setModel($property)
            ->unlinkImage()
            ->deleteFileDatabase()
            ->delete();
        return deleted_responses('properties');

    }

    public function propertyUnits($id): \Illuminate\Contracts\Pagination\LengthAwarePaginator
    {
        $propertyId = $this->service->find($id)->id;

        $orderBy = request()->get('orderBy', 'asc');

        if (!in_array($orderBy, ['asc', 'desc'])) {
            $orderBy = 'asc';
        }
        return Unit::with(['status:id,name,class', 'property','unit'])
            ->where('property_id', $propertyId)
            ->orderBy('id',   $orderBy)
            ->paginate(request('per_page', 10));
    }

    public function unitCards() : array
    {
        $totalSoldProperty = $this->service->totalSoldProperty();
        $totalUnsoldProperty = $this->service->totalUnsoldProperty();
        return [
            'totalSoldProperty' => $totalSoldProperty,
            'totalUnsoldProperty' => $totalUnsoldProperty,
        ];
    }

    public function  getInvNumber()
    {
        // Get the invoice starting number from the settings table
        $setting = Setting::where('name', 'invoice_starting_number')->first();

        // Get the latest invoice's id (or modify this if you are using a different column for invoice number)
        $invoice = Invoice::withTrashed()->select('id')->orderByDesc('id')->first();

        // Ensure a fallback in case there's no invoice in the database yet
        $latestInvoiceId = $invoice ? $invoice->id : 0;

        // Add the starting number from the settings to the latest invoice id
        $invoiceNumber = (int) $latestInvoiceId + (int) $setting->value;

        // Return the computed invoice number as JSON
        return response()->json(['invoice_number' => $invoiceNumber]);


    }


}

