<?php


namespace App\Http\Controllers\App\Unit;


use App\Filters\Patch\Units\UnitBookingFilter;
use App\Http\Controllers\Controller;
use App\Models\Commission;
use App\Models\Core\Setting\Setting;
use App\Models\Invoice;
use App\Models\InvoiceItem;
use App\Models\Payment;
use App\Models\Property;
use App\Models\Prospect;
use App\Models\ReservedUnitPayment;
use App\Models\Unit;
use App\Models\UnitBooking;
use App\Services\Patch\Liason\UnitBookingService;
use Illuminate\Http\Request;
use Illuminate\Support\Carbon;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Log;


class   UnitBookingController  extends Controller
{

    public function __construct(UnitBookingService $service, UnitBookingFilter $filter)
    {
        $this->service = $service;
        $this->filter = $filter;


    }

    public function index()
    {
        $user = Auth::user();

        $query = UnitBooking::with([
            'property:id,project_name',
            'unit',
            'user' => function ($query) {
                $query->with('profilePicture', 'status:id,name,class', 'profile:id,user_id,address,contact');
            },
            'plan',
            'customer',

        ])->filters($this->filter);


        if (!$user->isAppAdmin()) {
            $query->where('user_id', $user->id);
        }

        return $query->orderBy('id', request()->get('orderBy'))
            ->paginate(request('per_page', 10));

    }

    public function show($id)
    {

        return $this->service->with(['status:id,name,class','property','unit', 'plan',
            'customer',])->find($id);
    }

    public function store(Request $request)
    {
        try{
//            $paymentStartDate = $request->input('payment_start_date');
//            $sanitizedDate = date('Y-m-d', strtotime($paymentStartDate));
//            $request['payment_start_date'] = $sanitizedDate;
            // Define validation rules
            $rules = [
                'property_id' => 'required|exists:properties,id',
                'unit_id' => 'required|exists:units,id',
                'customer_id' => 'required',
                'payment_mode' => 'required',
                'amount' => 'required',
                'monthly_payment' => 'required',
                'payment_start_date' => 'required|date'
            ];

            // Validate the request data
            $request->validate($rules);

            $requestData = $request->only(['property_id', 'unit_id', 'user_id', 'plan_id','customer_id','posting_date','note','recurring','recurring_cycle_id',
                'document_date','installment_date','payment_start_date', 'status_id','payment_status_id','reference_number','payment_mode', 'amount','invoice_number','loan_amount','monthly_payment']);

            $requestData['user_id'] = Auth::id();
            $requestData['status_id'] = 16;  // Or any value based on your logic
            $requestData['payment_status_id'] = 16;  // Or any value based on your logic

            $requestData['document_status_id'] = 23;  // Or any value based on your logic


            // Get the invoice starting number from the settings table
            $setting = Setting::where('name', 'invoice_starting_number')->first();

            // Get the latest invoice's id (or modify this if you are using a different column for invoice number)
            $invoice = Invoice::withTrashed()->select('id')->orderByDesc('id')->first();

            // Ensure a fallback in case there's no invoice in the database yet
            $latestInvoiceId = $invoice ? $invoice->id : 0;

            // Add the starting number from the settings to the latest invoice id
            $invoiceNumber = (int) $latestInvoiceId + (int) $setting->value;

            $requestData['invoice_id'] = $invoiceNumber;


            $savedItem = $this->service->setAttributes($requestData)->save();

            $savedItemId = $savedItem->id; // Assuming the save method returns the saved model


            $unitIdToUpdate = $request->input('unit_id');
            $newStatusId = 11;

            $unit = Unit::findOrFail($unitIdToUpdate);

            $saleAmount = $unit->sale_amount;
            $unit->status_id = $newStatusId;
            $unit->invoice_id= $invoiceNumber;
            $unit->save();

            $amount = $request->input('amount');
//        $invoice_number = $request->input('invoice_number');

            // Step 2: Calculate the processing fee as 3% of the sale_amount
            //TODO: Add the STIMA PROJECT SCHEDULE
            $processingFee = 117958;

            $total = $saleAmount + $processingFee;

            $due_amount = $total -$amount;

            $invoiceData = [
                'client_id' => $request->input('customer_id'),  // Assuming customer is the client
                'invoice_number' => $invoiceNumber,
                'unit_id' => $request->input('unit_id'),
                'date' => Carbon::now(),
                'due_date' =>Carbon::parse($request->input('payment_start_date'))->addYears($request->input('number_of_years')),// $request->input('payment_start_date'),
                'recurring'=>$request->input('recurring'),
                'recurring_cycle_id'=>$request->input('recurring_cycle_id'),
                'status_id' => 7,  // You can adjust based on your logic
                'sub_total' => $saleAmount ,
                'discount_type' => 'none',
                'discount' => 0,
                'processing_fee' => $processingFee,
                'total' =>  $total,
                'due_amount'=>$due_amount,
                'received_amount' => $amount,  // Initial received amount
                'created_by'=> $request->input('user_id'),
                'notes' => 'Ruaka Heights LLP 01192855640800',
                'terms' => 'Thank you for your business!'
            ];

            $invoice = Invoice::create($invoiceData);




            InvoiceItem::create([
                'invoice_id' => $invoice->id,
                'unit_id' => $savedItemId,
                'quantity' => 1,
                'price' => $total,
            ]);

            $unitBooking = UnitBooking::findOrFail($savedItemId);
            $unitBooking->invoice_id = $invoice->id;
            $unitBooking->save();


            Payment::create([
                'invoice_id' => $invoice->id,
                'payment_method_id'=>1,
                'received_on' => Carbon::now(),
                'amount' => $amount,
                'payment_status_id'=> 16,
                'note'=>'Thank you for your business!',
                'created_by'=>$requestData['user_id'] = Auth::id()
            ]);

            $property = $request->input('property_id');
            $paymentThreshold = 0.25 * $saleAmount;
            $paymentAmount = $amount;
            $commissionAmount = 0;

            if ($property == 9) {
                if ($paymentAmount >= $paymentThreshold) {
                    // Agent is entitled to the full commission (3% of the unit price)
                    $commissionAmount = 0.03 * $saleAmount;
                }

                // Assume company share is a fixed percentage, e.g., 10%
                $companySharePercentage = 10;
                $companyShareAmount = ($companySharePercentage / 100) * $commissionAmount;

                // Store commission in the commissions table if a commission is calculated
                if ($commissionAmount > 0) {
//                    Commission::create([
//                        'invoice_id' => $invoice->id, // Store the invoice ID
//                        'property_id' => $property,
//                        'unit_id' => $request->input('unit_id'),
//                        'agent_id' => Auth::id(), // assuming agent_id is the authenticated user ID
//                        'commission_amount' => $commissionAmount,
//                        'company_share_amount' => $companyShareAmount,
//                    ]);
                }
            }


            $resunit = ReservedUnitPayment::where('unit_id', $unitIdToUpdate)->first();
            $prospect = Prospect::where('unit_id', $unitIdToUpdate)->first();

            if ($resunit || $prospect) {
                $modelInstance = $resunit ?? $prospect;
                $modelInstance->status_id = $newStatusId;

                if ($modelInstance->save()) {
                    return created_responses('bookings');
                } else {
                    return created_responses('bookings');
                }
            } else {
                return created_responses('bookings');
            }

        }
        catch (\Exception $exception){
            return $exception->getMessage();
        }
    }

    public function update(Request $request, UnitBooking $unit)
    {
        $this->service
            ->setModel($unit)
            ->setValidation()
            ->setAttributes($request->all())
            ->update();
        return updated_responses('bookings');

    }

    public function destroy(UnitBooking $unit)
    {
        $this->service
            ->setModel($unit)
            ->delete();
        return deleted_responses('bookings');

    }



}