<?php


namespace App\Http\Controllers\App\Unit;


use App\Filters\Patch\Property\PatchPropertyFilter;
use App\Http\Controllers\Controller;
use App\Services\Patch\Liason\ReservedUnitService;

use App\Filters\Patch\Agent\AgentLeedFilter;
use App\Models\AgentLead;
use App\Models\Core\Auth\User;
use App\Models\ReservedUnitPayment;
use App\Services\Core\AgentLeed\AgentLeedService;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;

class UnitReserveController  extends Controller
{

    public function __construct(ReservedUnitService $service,PatchPropertyFilter $filter)
    {
        $this->service = $service;
        $this->filter = $filter;
    }

    public function index()
    {

        $user = Auth::user();

        $query = ReservedUnitPayment::with([
            'unit','status:id,name,class',
            'property:id,project_name',
            'user:id,first_name,last_name'

        ])->where('status_id',12)
            ->filters($this->filter);

        if (!$user->isAppAdmin()) {
            $query->where('created_by', $user->id);
        }

//        return $query->orderBy('id', request()->get('orderBy'))
//            ->paginate(request('per_page', 10));

        // Fetch the paginated result
        $results = $query->orderBy('id', request()->get('orderBy'))
            ->paginate(request('per_page', 10));

        // Map the result to add sale_amount at the top level
        $results->getCollection()->transform(function ($item) {
            $item->sale_amount = $item->unit->sale_amount; // Add sale_amount at the top level
            return $item;
        });

        return $results;
    }


    public function show($id)
    {

        return $this->service->with(['status:id,name,class','property','unit'])->find($id);

    }


    public function store(Request $request)
    {
        $requestData = $request->all();
        $requestData['created_by'] = Auth::id();
        $this->service
            ->setValidation()
            ->setAttributes($requestData)
            ->save();

        return created_responses('crud');
    }

    public function update(Request $request, AgentLead $agentLead)
    {
        $this->service
            ->setModel($agentLead)
            ->setValidation()
            ->setAttributes($request->all())
            ->update();

        return updated_responses('agents');
    }

    public function destroy(AgentLead $agentLead)
    {
        $this->service
            ->setModel($agentLead)
            ->delete();
        return deleted_responses('agents');
    }

}