<?php

namespace App\Models;

use App\Models\Core\Auth\User;
use App\Models\Core\BaseModel;
use App\Models\Core\File\File;
use App\Models\Patch\Address\ClientAddress;
use App\Models\Patch\Country\Country;
use App\Models\Patch\Traits\EmailRelationshipTrait;
use App\Models\Patch\Traits\PhoneRelationshipTrait;
use Carbon\Carbon;
use Carbon\Traits\Creator;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\Relations\BelongsTo;
use Illuminate\Database\Eloquent\Relations\HasMany;
use Illuminate\Database\Eloquent\SoftDeletes;


class Customer extends BaseModel
{
    use HasFactory,
          EmailRelationshipTrait,
        PhoneRelationshipTrait;

    protected $fillable=[
        'user_id',
        'id_number',
        'kra_pin',
        'gender',
        'dob',
        'full_name',
        'email',
        'created_by',
        'postal_code',
        'country_id',
        'phone',
        'box_address',
        'location_address',
        'bank_name',
        'bank_branch',
        'account_name',
        'account_no',
        'currency',
        'swift_code',
        'bank_slip',
        'kin_name',
        'kin_id',
        'kin_kra_pin',
        'kin_gender',
        'kin_email',
        'kin_phone',
        'kin_box_address',
        'kin_location_address',
        'created_by'
    ];

    protected $hidden = [
        'created_at',
        'updated_at'
    ];

    public function setDobAttribute($value)
    {
        $this->attributes['dob'] = (new Carbon($value))->format('y-m-d');
    }
    public function country(): BelongsTo
    {
        return $this->belongsTo(Country::class);
    }


    public function customer(): BelongsTo
    {
        return $this->belongsTo(Agent::class);
    }

    public function addresses(): HasMany
    {
        return $this->hasMany(ClientAddress::class);
    }

    public function attachment()
    {
        return $this->morphOne(File::class, 'fileable');
    }

    public function user(): BelongsTo
    {
        return $this->belongsTo(User::class,'user_id');
    }

}
