<?php


namespace App\Models;

use App\Models\Core\BaseModel;
use App\Models\Core\File\File;
use App\Models\Core\Status;
use App\Models\Core\Traits\CreatedByRelationship;
use Carbon\Carbon;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Support\Collection;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\Relations\MorphOne;

use Illuminate\Database\Eloquent\Relations\BelongsTo;


class Property extends BaseModel
{
    use HasFactory, HasFactory, CreatedByRelationship;

    protected $table = 'properties';

    protected $fillable = [
        'project_name',
        'property_code',
        'property_name',
        'property_photo',
        'property_status',
        'property_type_id', // e.g apartment, commercial, duplex, house, mixed_use, other
        'location',
        'latitude',
        'longitude',
        'address_1',
        'address_2',
        'country',
        'unit_no',
        'posting_date',
        'document_date',
        'business_code',
        'project_code',
        'state',
        'city',
        'agent_commission_value',
        'agent_commission_type',
    ];

    public function setPostingDateAttribute($value)
    {
        $this->attributes['posting_date'] = (new Carbon($value))->format('y-m-d');
    }

    public function setDocumentDateAttribute($value)
    {
        $this->attributes['document_date'] = (new Carbon($value))->format('y-m-d');
    }



    public function file(): MorphOne
    {
        return $this->morphOne(File::class, 'fileable');
    }


    public function status(): BelongsTo
    {
        return $this->belongsTo(Status::class);
    }


}
