<?php

namespace App\Models;

use App\Models\Core\BaseModel;
use App\Models\Core\File\File;
use App\Models\Core\Status;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Relations\BelongsTo;
use Illuminate\Database\Eloquent\Relations\MorphOne;


class Unit extends BaseModel
{


    use HasFactory;

    protected $fillable = [
        'property_id',
        'unit_name',
        'sale_amount',
        'initial_amount',
        'unit_floor',
        'status_id',
        'unit_type_id',
        'total_rooms',
        'square_foot'
    ];

    public function file(): MorphOne
    {
        return $this->morphOne(File::class, 'fileable');
    }

    public function status(): BelongsTo
    {
        return $this->belongsTo(Status::class);
    }

//    public function getSaleAmountAttribute($value)
//    {
//        return number_format($value, 2);
//    }


    public function unit_type()
    {
        return $this->belongsTo(UnitType::class, 'unit_type_id');
    }

    public function unit(): BelongsTo
    {
        return $this->belongsTo(UnitType::class,'unit_type_id');
    }


    public function property()
    {
        return $this->belongsTo(Property::class, 'property_id');
    }

    public function amenities()
    {
        return $this->belongsToMany(Amenity::class, 'amenity_unit', 'unit_id', 'amenity_id');
    }

    public function utilities()
    {
        return $this->belongsToMany(Utility::class, 'unit_utility', 'unit_id', 'utility_id');
    }

    public function invoiceItems(): \Illuminate\Database\Eloquent\Relations\HasMany
    {
        return $this->hasMany(InvoiceItem::class);
    }


}
