<?php


namespace App\Services\Patch\Liason;


use App\Models\Commission;
use App\Models\Core\Status;
use App\Models\Invoice;
use App\Models\Payment;
use App\Services\Patch\ApplicationBaseService;
use PDF;
use Illuminate\Support\Facades\Storage;

class PaymentHistoryService  extends ApplicationBaseService
{

    public function __construct(Payment $payment)
    {
        $this->model = $payment;
    }

    public function setValidation(): self
    {
        validator(request()->all(), [
            'invoice_id' => 'required',
            'payment_method_id' => 'required',
            'received_on' => 'required',
            'amount' => 'required'
        ], [
            'invoice_id.required' => 'The invoice field is required.',
            'payment_method_id.required' => 'The payment method field is required.',
        ])->validate();

        return $this;
    }

    public function dueAmountUpdate(): self
    {
        $invoice = Invoice::where('id', request('invoice_id'));
        $invoice->decrement('due_amount', request('amount'));
        $invoice->increment('received_amount', request('amount'));
        //Status adjustment
        $this->statusAdjustment($invoice);
        return $this;
    }

    public function adjustDueAmount(): self
    {
        $invoice = Invoice::where('id', request('invoice_id'));
        if (request('amount') != request('old_amount')) {
            if (request('amount') > request('old_amount')) {
                $invoice->decrement('due_amount', (request('amount') - request('old_amount')));
                $invoice->increment('received_amount', (request('amount') - request('old_amount')));
            } else {
                $invoice->increment('due_amount', (request('old_amount') - request('amount')));
                $invoice->decrement('received_amount', (request('old_amount') - request('amount')));
            }
        }
        //Status adjustment
        $this->statusAdjustment($invoice);
        return $this;
    }

    public function commissionAgent(): self
    {
        // Fetch the invoice using the invoice_id from the request
        $invoice = Invoice::with('unitBooking.property')->where('id', request('invoice_id'))->firstOrFail();

        // Extract unit and property based on relationships
        $unitBooking = $invoice->unitBooking;
        $property = $unitBooking->property;

        $unitPrice = $unitBooking->unit->sale_amount;
        $paymentThreshold = 0.25 * $unitPrice;

        // Calculate commission based on the payment amount
        $paymentAmount = request('amount');


        $commissionAmount = 0;
        if ($paymentAmount >= $paymentThreshold) {
            // Agent is entitled to the full commission (3% of the unit price)
            $commissionAmount = 0.03 * $unitPrice;
        }

        // Assume company share is a fixed percentage, e.g., 10%
        $companySharePercentage = 10;
        $companyShareAmount = ($companySharePercentage / 100) * $commissionAmount;


        // Store commission in the commissions table if a commission is calculated
        if ($commissionAmount > 0) {
            Commission::create([
                'invoice_id' => $invoice->id, // Store the invoice ID
                'property_id' => $property->id,
                'unit_id' => $unitBooking->unit_id,
                'agent_id' => $unitBooking->user_id, // assuming agent_id is available in unitBooking
                'commission_amount' => $commissionAmount,
                'company_share_amount' => $companyShareAmount,
            ]);
        }

        return $this;
    }

    /**
     * @param $invoice
     */
    public function statusAdjustment($invoice): void
    {
        $invoiceData = $invoice->first();
        $paidStatusId = Status::findByNameAndType('status_paid', 'invoice')->id;
        $partiallyPaidStatusId = Status::findByNameAndType('status_partially_paid', 'invoice')->id;
        if ($invoiceData->received_amount == $invoiceData->total) {
            $invoice->update([
                'status_id' => $paidStatusId
            ]);
        } elseif ($invoiceData->received_amount < $invoiceData->total) {
            $invoice->update([
                'status_id' => $partiallyPaidStatusId
            ]);
        }
    }


    public function pdfGenerate($invoiceInfo):self
    {
        $pdf = PDF::loadView('invoices.invoice-generate', [
            'invoice' => $invoiceInfo
        ]);

        $output = $pdf->output();
        $filePath = $this->getAttribute('file_path');
        Storage::put($filePath, $output);
        return $this;
    }

}
