<?php


namespace App\Services\Patch\Liason;


use App\Helpers\Core\Traits\FileHandler;
use App\Helpers\Core\Traits\HasWhen;
use App\Models\TitleDeed;
use App\Services\Patch\ApplicationBaseService;

class TitleDeedService  extends ApplicationBaseService
{
    use FileHandler, HasWhen;
    public function __construct(TitleDeed $title)
    {
        $this->model = $title;
    }

    public function checkValidation(): self
    {
        validator(request()->all(), [
            'name' => 'required|max:191',
            'unit_id' => 'required|numeric',
            'property_id' => 'required|numeric',
            'attachment' => 'nullable|mimes:jpeg,jpg,gif,png,doc,pdf,zip|max:10140',
        ],[
            'unit_id.required' => 'The unit field is required.',
            'unit_id.numeric' => 'The unit field is numeric value.',
            'property_id.required' => 'The property field is required.',
            'property_id.numeric' => 'The property field is numeric value.'
        ])->validate();

        return $this;
    }

    public function saveAttachment($file): self
    {
        $this->deleteFile(optional($this->model->file)->path);

        $file_path = $this->storeFile(
            $file,
            'titles'
        );

        $this->model->attachment()->updateOrCreate([
            'type' => 'titles',
        ], [
            'path' => $file_path
        ]);

        return $this;
    }

    public function deleteAttachment(): self
    {
        $this->deleteFile(optional($this->model->attachment)->path);

        return $this;
    }
    public function deleteAttachmentData(): self
    {
        $this->model->attachment()->delete();

        return $this;
    }


}