<?php


namespace App\Services\Patch\Liason;


use App\Services\Patch\ApplicationBaseService;

class TpsPaymentService  extends ApplicationBaseService
{

    /**
     * Fixed values for deposit and interest rate
     */
    const DEPOSIT_PERCENTAGE = 0.25;  // 25%
    const ANNUAL_INTEREST_RATE = 0.07; // 7%

    /**
     * Calculate the loan amount after applying fixed 25% deposit
     *
     * @param  float  $saleAmount
     * @return float
     */
    public function calculateLoanAmount(float $saleAmount)
    {
        return $saleAmount * (1 - self::DEPOSIT_PERCENTAGE); // Loan amount after deposit
    }

    /**
     * Calculate Monthly TPS Payment using fixed interest rate and loan term
     *
     * @param  float  $loanAmount
     * @param  int    $termYears // Loan term in years
     * @return float
     */

    public function calculateMonthlyTPS(float $loanAmount, int $termYears)
    {
        // Monthly interest rate
        $monthlyInterestRate = self::ANNUAL_INTEREST_RATE / 12;

        // Total number of monthly payments
        $totalPayments = $termYears * 12;

        // Amortization formula for calculating monthly payment
        return ($loanAmount * $monthlyInterestRate * pow(1 + $monthlyInterestRate, $totalPayments)) /
            (pow(1 + $monthlyInterestRate, $totalPayments) - 1);
    }

}