import AppFunction from '../../core/helpers/app/AppFunction';
import {CONFIRMPAYMENTHISTORY} from "../Config/PatchApiUrls";
import {formatDateToLocal, numberWithCurrencySymbol} from "../Helpers/Helpers";
import {DeleteMixins, ModalMixins} from "./patch/DeleteMixins";
import {FormMixin} from "../../core/mixins/form/FormMixin";
import {paymentMethods} from "./FilterMixin";
import {urlGenerator} from "../Helpers/AxiosHelper";
import * as actions from "../Config/ApiUrl";

export default {
    mixins: [FormMixin, DeleteMixins, ModalMixins, paymentMethods],
    data() {
        return {
            tableId: 'payments-table',
            paymentSummation: {},
            numberWithCurrencySymbol,
            options: {
                url: CONFIRMPAYMENTHISTORY,
                name: this.$t('payments_table'),
                filters: [
                    {
                        'title': this.$t('created'),
                        'type': 'range-picker',
                        'key': 'date',
                        'option': ['today', 'thisMonth', 'last7Days', 'nextYear']
                    },
                    {
                        title: this.$t("payment_methods"),
                        type: "checkbox",
                        key: "payment_methods",
                        option: [],
                        permission: this.$can('show_all_data') ? true : false
                    },
                    {
                        title: this.$t("clients"),
                        type: "search-and-select-filter",
                        key: "clients",
                        settings: {
                            url: urlGenerator('client-users'),
                            modifire: (item) => {
                                return {id: item.id, value: item.full_name}
                            },
                            per_page: 10,
                            loader: 'app-pre-loader',
                            multiple: true,
                        },
                        permission: this.$can('show_all_data') ? true : false
                    },
                    {
                        title: this.$t("amount"),
                        type: "range-filter",
                        key: "amount_range",
                        minTitle: this.$t('minimum_amount'),
                        maxTitle: this.$t('maximum_amount'),
                        maxRange: 100,
                        minRange: 0,
                        permission: this.$can('show_all_data') ? true : false
                    },
                ],
                columns: [
                    {
                        title: this.$t('invoice_number'),
                        type: 'object',
                        key: 'invoice',
                        modifier: (invoice => invoice ? invoice.invoice_number : '')
                    },
                    {
                        title: this.$t('client'),
                        type: 'object',
                        key: 'invoice',
                        isVisible: !!this.$can('show_all_data'),
                        modifier: (invoice => invoice?.client ? invoice?.client?.full_name : '')
                    },
                    {
                        title: this.$t('date'),
                        type: 'object',
                        key: 'received_on',
                        modifier: (received_on => formatDateToLocal(received_on))
                    },
                    {
                        title: this.$t('payment_method'),
                        type: 'object',
                        key: 'payment_method',
                        modifier: (payment_method => payment_method ? payment_method.name : '')

                    }
                    ,
                    {
                        title: this.$t('amount'),
                        type: 'object',
                        key: 'amount',
                        modifier: (amount => numberWithCurrencySymbol(amount))
                    },
                    {
                        title: 'Payment Note',
                        type: 'component',
                        componentName: 'payment-note',
                        key: 'note',
                        modifier: (note => {
                            if (note){
                                return true;
                            }else{
                                return false;
                            }
                        })
                    },

                    {
                        title: this.$t('status'),
                        type: 'custom-html',
                        key: 'payment_status',
                        isVisible: true,
                        modifier: (value) => {
                            return `<span class="badge badge-${value.class} badge-pill mr-2">${value.translated_name}</span>`
                        }
                    },
                ],
                actions: [

                    {
                        title: 'Confirm Payment',
                        type: 'payment-confirm',
                        modifier: (rowData) => {
                            return rowData.payment_status?.name === 'pending_confirmation' ? true : false
                        },
                    },
                ],
                rowLimit: 10,
                orderBy: 'desc',
                responsive: true,
                showHeader: true,
                showFilter: true,
                showSearch: true,
                showAction: true,
                tableShadow: true,
                actionType: 'dropdown',
                datatableWrapper: true,
                paginationType: 'pagination'
            },
        }
    },
    methods: {
        getListAction(rowData, actionObj) {
            this.selectUrl = `${CONFIRMPAYMENTHISTORY}/${rowData.id}`
            if (actionObj.title === this.$t('edit')) {
                this.isModalActive = true;
            }
            else if (actionObj.type === 'payment-confirm') {
                this.changePaymentStatus(15, rowData.id);
            }
        },

        viewClientDetails() {
            location.replace(AppFunction.getAppUrl('/client-details'));
        },
        getTableMediaAction() {
            this.$hub.$on('getTableMediaAction', (data) => {
                this.viewInvoiceDetails();
            })
        },

        PaymentRangeFilter() {
            this.axiosGet(`payment-range-filter`).then((response) => {
                let amountValueFilter = this.options.filters.find(item => item.key === 'amount_range');

                amountValueFilter.maxRange = response.data.max_amount;
                amountValueFilter.minRange =
                    response.data.min_amount < response.data.min_amount ? response.data.max_amount : 0;
            });
        },

        getPaymentSummation() {
            this.axiosGet(`payment-summation`).then((response) => {
                this.paymentSummation = response.data;
            })
        },

        changePaymentStatus(status, unitInfo) {
            let url = `${actions.CONFIRMPAYMENTHISTORY}/${unitInfo}`,
                reqData = { payment_status_id: status }; // Only sending the payment_status_id
            // reqData.payment_status_id = status;
            this.axiosPatch({
                url: url,
                data: reqData
            }).then(res => {
                this.$toastr.s(res.data.message);
            }).catch(error => {
                let {message} = error.response.data;
                this.$toastr.e(message);
            }).finally(() => {
                this.$hub.$emit('reload-' + this.tableId);
            });
        }


    },
    mounted() {
        this.getTableMediaAction();
        this.$store.dispatch("getInvoice");
        if (this.$can('show_all_data')) {
            this.PaymentRangeFilter();
        }
    },
    created() {
        if (this.$can("update_payment_histories") || this.$can("delete_payment_histories")) {
            this.options.columns = [...this.options.columns, {
                title: this.$t('action'),
                type: 'action',
                key: 'invoice',
                isVisible: true
            },]
        }
        this.getPaymentSummation();
    }
}