import AppFunction from "../../core/helpers/app/AppFunction";
import {LEGAL_PROCESS_OFFER_LETTER,OFFER_LETTER_PAYMENT} from "../Config/PatchApiUrls";
import {FormMixin} from "../../core/mixins/form/FormMixin";
import {DeleteMixins, ModalMixins} from "./patch/DeleteMixins";
import {countries} from "./patch/FilterMixins";
import {mapGetters} from "vuex";
import * as actions from '../Config/ApiUrl';
import { urlGenerator} from "../Helpers/AxiosHelper";
import {numberWithCurrencySymbol} from "../Helpers/Helpers";


export default {
    mixins: [FormMixin, DeleteMixins, ModalMixins, countries],
    data(){
        return{
            tableId: 'project-unit-table',
            rowData: {},
            options:{
                url: LEGAL_PROCESS_OFFER_LETTER,
                name: "Project Units",



                filters: [
                    {
                        'title': this.$t('created'),
                        'type': 'range-picker',
                        'key': 'date',
                        'option': ['today', 'thisMonth', 'last7Days', 'nextYear']
                    },

                ],

                columns: [
                    {
                        title: 'Project',
                        type: 'object',
                        key: 'property',
                        modifier: (property) => {
                            return property ? property.project_name : '-';
                        }
                    },

                    {
                        title: 'Unit Name',
                        type: 'object',
                        key: 'unit',
                        modifier: (unit) => {
                            return unit? unit.unit_name : '-';
                        }
                    },
                    {
                        title: 'Unit Floor Number',
                        type: 'object',
                        key: 'unit',
                        modifier: (unit) => {
                            return unit? unit.unit_floor : '-';
                        }
                    },

                    {
                        title: 'Sold By (Agent)',
                        type: 'object',
                        key: 'user',
                        modifier: (user) => {
                            return user ? user.full_name : '-';
                        }
                    },


                    {
                        title: 'Customer',
                        type: 'object',
                        key: 'customer',
                        modifier: (customer) => {
                            // return user ? `${user.first_name} ${user.last_name}` : '-';

                            return customer ? customer.full_name : '-';
                        }
                    },

                    {
                        title: 'Unit Payment Plan',
                        type: 'object',
                        key: 'plan',
                        modifier: (plan) => {
                            return plan? plan.name : '-';
                        }
                    },



                    {
                        title: 'Amount Received',
                        type: 'text',
                        key: 'amount',
                        modifier: (amount) => {
                            return numberWithCurrencySymbol(amount);
                        },
                    },


                    {
                        title: 'Unit Cost (KES)',
                        type: 'object',
                        key: 'unit',
                        modifier: (unit) => {
                            return unit && unit.sale_amount ? numberWithCurrencySymbol(unit.sale_amount) : '-';

                        }
                    },
                    {
                        title: this.$t('status'),
                        type: 'custom-html',
                        key: 'payment_status',
                        isVisible: true,
                        modifier: (value) => {
                            return `<span class="badge badge-${value.class} badge-pill mr-2">${value.translated_name}</span>`
                        }
                    },


                    {
                        title: 'Document Status',
                        type: 'custom-html',
                        key: 'document_status',
                        isVisible: true,
                        modifier: (value) => {
                            return `<span class="badge badge-${value.class} badge-pill mr-2">${value.translated_name}</span>`
                        }
                    },

                    {
                        title: this.$t('actions'),
                        type: 'action'
                    }
                ],

                actions: [
                    {
                        title: this.$t('view'),
                        type: 'view',
                    },
                    {
                        title: 'Upload Document',
                        type: 'create',
                    }
                ],


                rowLimit: 10,
                orderBy: 'desc',
                responsive: true,
                showHeader: true,
                showFilter: true,
                showSearch: true,
                showAction: true,
                tableShadow: true,
                actionType: 'dropdown',
                datatableWrapper: true,
                paginationType: 'pagination'

            }

        }
    },
    computed:{
    },
    methods: {
        getListAction(rowData, actionObj) {
            this.selectUrl = `${LEGAL_PROCESS_OFFER_LETTER}/${rowData.id}`;
            if (actionObj.type === 'view') {
                location.replace(AppFunction.getAppUrl(`unit/lead/offer/letter/${rowData.id}/details`));
            }

            if (actionObj.type === 'create') {
                this.isModalActive = true;

            }

        },
        closeModal() {
            this.isModalActive = false;
        },
    }

}
