import AppFunction from "../../core/helpers/app/AppFunction";
import {CONFIRMPAYMENTHISTORY, PROCESSTITLEDEEDS} from "../Config/PatchApiUrls";
import {FormMixin} from "../../core/mixins/form/FormMixin";
import {formatDateToLocal, numberWithCurrencySymbol} from "../Helpers/Helpers";

import {DeleteMixins, ModalMixins} from "./patch/DeleteMixins";
import {countries} from "./patch/FilterMixins";
import {mapGetters} from "vuex";
import * as actions from "../Config/ApiUrl";
import {axiosGet, axiosPatch,urlGenerator} from "../Helpers/AxiosHelper";
import { status} from "./FilterMixin";



export default {
    mixins: [FormMixin, DeleteMixins, status],
    data() {
        return {
            AppFunction,
            tableId: 'title-deeds-table',
            productList: [],
            isInvoicePaymentModalActive: false,
            clientModalActive: false,
            options: {
                url: PROCESSTITLEDEEDS,
                name: this.$t('invoices_table'),
                filters: [

                ],
                columns: [

                    {
                        title: 'Client Name',
                        type: 'object',
                        key: 'client',
                        modifier: (client => client ? client.full_name : '')
                    },

                    {
                        title: 'Client Email',
                        type: 'object',
                        key: 'client',
                        modifier: (client => client ? client.email : '')
                    },


                    {
                        title: 'Unit Name',
                        type: 'object',
                        key: 'unit',
                        modifier: (unit) => {
                            return unit? unit.unit_name : '-';
                        }
                    },

                    {
                        title: 'Unit Floor Number',
                        type: 'object',
                        key: 'unit',
                        modifier: (unit) => {
                            return unit? unit.unit_floor : '-';
                        }
                    },

                    {
                        title: 'Unit Area(sqft)',
                        type: 'object',
                        key: 'unit',
                        modifier: (unit) => {
                            return unit? unit.square_foot : '-';
                        }
                    },
                    {
                        title: this.$t('issue_date'),
                        type: 'object',
                        key: 'date',
                        modifier: (date => formatDateToLocal(date))
                    }, {
                        title: this.$t('due_date'),
                        type: 'object',
                        key: 'due_date',
                        modifier: (due_date => formatDateToLocal(due_date))
                    },
                    {
                        title: this.$t('total'),
                        type: 'object',
                        key: 'total',
                        modifier: (total => numberWithCurrencySymbol(total))
                    },
                    {
                        title: this.$t('paid'),
                        type: 'object',
                        key: 'received_amount',
                        modifier: (received_amount => numberWithCurrencySymbol(received_amount))
                    },
                    {
                        title: this.$t('amount_due'),
                        type: 'object',
                        key: 'due_amount',
                        modifier: (due_amount => numberWithCurrencySymbol(due_amount))
                    },

                    {
                        title: this.$t('status'),
                        type: 'custom-html',
                        key: 'status',
                        isVisible: true,
                        modifier: (value) => {
                            return `<span class="badge badge-${value.class} badge-pill mr-2">${value.translated_name}</span>`
                        }
                    },
                    {
                        title: 'Title Status',
                        type: 'custom-html',
                        key: 'title_status',
                        isVisible: true,
                        modifier: (value) => {
                            return `<span class="badge badge-${value.class} badge-pill mr-2">${value.translated_name}</span>`
                        }
                    },
                    {
                        title: this.$t('actions'),
                        type: 'action'
                    }
                ],
                actions: [

                    {
                        title: 'Alert Collection',
                        type: 'payment-confirm',
                        modifier: (rowData) => {
                            return rowData.title_status?.name
                        },
                    },


                    {
                        title: 'Confirm Title Collected',
                        type: 'title-collected',
                        modifier: (rowData) => {
                            return rowData.title_status?.name
                        },
                    },

                ],
                rowLimit: 10,
                orderBy: 'desc',
                responsive: true,
                showHeader: true,
                showFilter: true,
                showSearch: true,
                showAction: true,
                tableShadow: true,
                actionType: 'dropdown',
                datatableWrapper: true,
                paginationType: 'pagination'
            },
            isInvoiceAddEditModalActive: false,
            isPaymentAddEditModalActive: false,

            numberWithCurrencySymbol
        }
    },
    computed: {
        ...mapGetters({
            recurringCycleList: "getRecurringCycle",
        }),

    },
    methods: {
        getListAction(rowData, actionObj) {
            this.selectUrl = `${PROCESSTITLEDEEDS}/${rowData.id}`
            if (actionObj.title === this.$t('edit')) {
                this.isModalActive = true;
            }
            else if (actionObj.type === 'payment-confirm') {
                this.changeTitleCollectionStatus(24, rowData.id);
            }
            else if (actionObj.type === 'title-collected') {
                this.changeTitleCollectionStatus(25, rowData.id);
            }
        },

        changeTitleCollectionStatus(status, unitInfo) {
            let url = `${actions.PROCESSTITLEDEEDS}/${unitInfo}`,
                reqData = { title_status_id: status }; // Only sending the payment_status_id
            // reqData.payment_status_id = status;
            this.axiosPatch({
                url: url,
                data: reqData
            }).then(res => {
                this.$toastr.s(res.data.message);
            }).catch(error => {
                let {message} = error.response.data;
                this.$toastr.e(message);
            }).finally(() => {
                this.$hub.$emit('reload-' + this.tableId);
            });
        },


    },
    mounted() {

    }

}
