import AppFunction from "../../core/helpers/app/AppFunction";
import {AGENT_LIST, PROJECT_DOCUMENTS_FETCH, PROJECT_UNITS_FETCH, PROPERTY_LIST} from "../Config/PatchApiUrls";
import {FormMixin} from "../../core/mixins/form/FormMixin";
import {DeleteMixins, ModalMixins} from "./patch/DeleteMixins";
import {countries} from "./patch/FilterMixins";
import {mapGetters} from "vuex";
import * as actions from '../Config/ApiUrl';
import { urlGenerator} from "../Helpers/AxiosHelper";
import {numberWithCurrencySymbol} from "../Helpers/Helpers";


export default {
    mixins: [FormMixin, DeleteMixins, ModalMixins, countries],
    data(){
        return{
            tableId: 'project-unit-table',
            rowData: {},
            isUnitModalActive: false,
            isPropertyModalActive: false,
            isCustomerModalActive: false,
            isProspectModalActive: false,

            options:{
                url: PROJECT_UNITS_FETCH,
                name: "Project Units",
                filters: [
                    {
                        'title': this.$t('created'),
                        'type': 'range-picker',
                        'key': 'date',
                        'option': ['today', 'thisMonth', 'last7Days', 'nextYear']
                    },

                ],

                columns: [

                    {
                        title: 'Project',
                        type: 'object',
                        key: 'property',
                        modifier: (property) => {
                            return property ? property.project_name : '-';
                        }
                    },


                    {
                        title: 'Property Name',
                        type: 'object',
                        key: 'property',
                        modifier: (property) => {
                            return property ? property.property_name : '-';
                        }
                    },
                    {
                        title: this.$t('unit_name'),
                        type: 'text',
                        key: 'unit_name',
                    },
                    {
                        title: 'Unit Type',
                        type: 'object',
                        key: 'unit',
                        modifier: (unit) => {
                            return unit ? unit.unit_type_name : '-';
                        }

                    },



                    {
                        title: this.$t('unit_floor'),
                        type: 'text',
                        key: 'unit_floor',
                    },


                    {
                        title: 'Square Feet(m2)',
                        type: 'text',
                        key: 'square_foot',
                    },


                    {
                        title: 'Unit Price(KES)',
                        type: 'object',
                        key:'sale_amount',
                        modifier: (sale_amount => numberWithCurrencySymbol(sale_amount))

                    },
                    {
                        title: this.$t('status'),
                        type: 'custom-html',
                        key: 'status',
                        isVisible: true,
                        modifier: (value) => {
                            return `<span class="badge badge-${value.class} badge-pill mr-2">${value.translated_name}</span>`
                        }
                    },

                    {
                        title: this.$t('actions'),
                        type: 'action'
                    }


                ],

                actions: [
                    // {
                    //     title: this.$t('view'),
                    //     type: 'view',
                    // },

                    {
                        title: 'Reserve Unit',
                        type: 'reserve',
                    },
                    {
                        title: 'Create Prospects',
                        type: 'create-prospect',
                    },
                    {
                        title: 'Make Payment',
                        type: 'create',
                    }


                ],

                rowLimit: 10,
                orderBy: 'desc',
                responsive: true,
                showHeader: true,
                showFilter: true,
                showSearch: true,
                showAction: true,
                tableShadow: true,
                actionType: 'dropdown',
                datatableWrapper: true,
                paginationType: 'pagination'

            }

        }
    },
    computed:{
    },
    methods: {

        afterSuccessFromGetEditData(response) {
            this.formData = response.data;
            this.dataLoaded = true;
        },
        getListAction(rowData, actionObj) {
            this.selectUrl = `${PROJECT_UNITS_FETCH}/${rowData.id}`;
            // if (actionObj.type === 'view') {
            //     location.replace(AppFunction.getAppUrl(`unit/for/sale/${rowData.id}/details`));
            // }
            if (actionObj.type === 'reserve') {
                this.isPropertyModalActive = true;
                this.isProspectModalActive = false;
                this.isUnitModalActive = false;

            }
            else if (actionObj.type === 'create-prospect') {
                this.isProspectModalActive = true;
                this.isPropertyModalActive = false;
                this.isUnitModalActive = false;


            }

            else if (actionObj.type === 'create') {
                this.isUnitModalActive = true;
                this.isPropertyModalActive = false;
                this.isProspectModalActive = false;
            }


        },

        closeModal() {
            this.isUnitModalActive = false;
            this.isPropertyModalActive = false;
            this.isProspectModalActive = false;
        },


    }

}
