import AppFunction from "../../core/helpers/app/AppFunction";
import {RESERVED_UNITS} from "../Config/PatchApiUrls";
import {FormMixin} from "../../core/mixins/form/FormMixin";
import {DeleteMixins, ModalMixins} from "./patch/DeleteMixins";
import {countries} from "./patch/FilterMixins";
import {mapGetters} from "vuex";
import * as actions from '../Config/ApiUrl';

export default {
    mixins: [FormMixin, DeleteMixins, ModalMixins, countries],

    data(){

        return{
            tableId: 'reserved-unit-payments',
            rowData: {},
            options:{
                url: RESERVED_UNITS,
                name: 'Reserved Unit Payments',
                filters: [
                    {
                        'title': this.$t('created'),
                        'type': 'range-picker',
                        'key': 'date',
                        'option': ['today', 'thisMonth', 'last7Days', 'nextYear']
                    },
                ],

                columns: [


                    {
                        title: 'Client Name',
                        type: 'text',
                        key: 'client_name',
                    },

                    {
                        title: 'Phone',
                        type: 'text',
                        key: 'phone',
                    },
                    {
                        title: 'Email Address',
                        type: 'text',
                        key: 'email',
                    },

                    {
                        title: 'Unit Name',
                        type: 'object',
                        key: 'unit',
                        modifier: (unit) => {
                            return unit ? unit.unit_name : '-';
                        }

                    },

                    {
                        title: 'Unit Price(KES)',
                        type: 'text',
                        key: 'amount',
                    },
                    {
                        title: 'Reference',
                        type: 'text',
                        key: 'reference_number',
                    },

                    {
                        title: 'Payment Mode',
                        type: 'text',
                        key: 'payment_mode',
                    },
                    {
                        title: 'Payment Note',
                        type: 'component',
                        componentName: 'payment-note',
                        key: 'note',
                        modifier: (note => {
                            if (note){
                                return true;
                            }else{
                                return false;
                            }
                        })
                    },
                    {
                        title: this.$t('status'),
                        type: 'custom-html',
                        key: 'payment_status',
                        isVisible: true,
                        modifier: (value) => {
                            return `<span class="badge badge-${value.class} badge-pill mr-2">${value.translated_name}</span>`
                        }
                    },


                    {
                        title: this.$t('actions'),
                        type: 'action'
                    }
                ],
                actions: [
                    {
                        title: 'Confirm Payment',
                        type: 'active',
                        modifier: (rowData) => {
                            return rowData.payment_status?.name === 'pending_confirmation' ? true : false
                        },
                    },
                ],

                rowLimit: 10,
                orderBy: 'desc',
                responsive: true,
                showHeader: true,
                showFilter: true,
                showSearch: true,
                showAction: true,
                tableShadow: true,
                actionType: 'dropdown',
                datatableWrapper: true,
                paginationType: 'pagination'


            }

        }

    },
    computed:{

    },
    methods:{
        getListAction(rowData, actionObj) {
            this.selectUrl = `${RESERVED_UNITS}/${rowData.id}`
            if (actionObj.type === 'active') {
                this.changePaymentStatus(15, rowData.id);
            }
        },
        openModal() {
            this.isModalActive = true;
        },

        changePaymentStatus(status, unitInfo) {
            let url = `${actions.RESERVED_UNITS}/${unitInfo}`,
                reqData = { payment_status_id: status }; // Only sending the payment_status_id
            // reqData.payment_status_id = status;
            this.axiosPatch({
                url: url,
                data: reqData
            }).then(res => {
                this.$toastr.s(res.data.message);
            }).catch(error => {
                let {message} = error.response.data;
                this.$toastr.e(message);
            }).finally(() => {
                this.$hub.$emit('reload-' + this.tableId);
            });
        }

    },

    mounted() {
    }

}
