<?php

use App\Http\Controllers\{App\Agent\AgentController,
    App\Amenity\AmenityController,
    App\CustomTable\DataTableCustomTableController,
    App\Properties\PropertyController,
    App\Properties\PropertyTypeController,
    App\Unit\UnitTypeController,
    App\Utility\UtilityController,
    Core\Auth\Role\PermissionController,
    Core\Auth\User\AuthenticateUserController,
    Core\Auth\User\LoginController,
    Core\Auth\User\UserPasswordController as BaseUserPasswordControllerAlias,
    Core\Auth\User\UserUpdateController,
    Core\Auth\User\UserThumbnailController,
    Core\Builder\Form\CustomFieldTypeController,
    Core\Builder\Table\CustomTableController,
    Core\Frontend\TableFilterController,
    Core\LanguageController,
    Core\Log\ActivityLogController,
    Core\Notification\NotificationChannelController,
    Core\Notification\NotificationController,
    Core\Notification\NotificationEventController,
    Core\Setting\StatusController,
    Core\Setting\TypeController,
    App\Customer\CustomerController};

Route::group(['prefix' => 'app'], function () {
    Route::get('types', [TypeController::class, 'index'])
        ->name('types.index');

    Route::get('statuses', [StatusController::class, 'index'])
        ->name('statuses.index');

    Route::get('notification-events', [NotificationEventController::class, 'index'])
        ->name('notification-events.index');

    Route::get('notification-events/{notification_event}', [NotificationEventController::class, 'show'])
        ->name('notification-events.show');

    Route::get('notification-channels', [NotificationChannelController::class, 'index'])
        ->name('notification-channels.index');

    Route::get('custom-field-types', [CustomFieldTypeController::class, 'index']);

    Route::resource('table-filter', TableFilterController::class)->except('create','edit', 'show');

    Route::get('custom-table/values/{custom_table}', [DataTableCustomTableController::class, 'getTableValues'])
        ->name('custom-table.field-values');

    Route::post('custom-table/values', [DataTableCustomTableController::class, 'storeTableValues'])
        ->name('custom-table.store-values');

    Route::get('custom-table/row/{custom_table_row}', [DataTableCustomTableController::class, 'getTableRow'])
        ->name('custom-table.row');

    Route::patch('custom-table/row/{custom_table_row}', [DataTableCustomTableController::class, 'updateTableRow'])
        ->name('custom-table.update-row');

    Route::delete('custom-table/row/{custom_table_row}', [DataTableCustomTableController::class, 'deleteTableRow'])
        ->name('custom-table.delete-row');

});

Route::get('auth/permissions', [PermissionController::class, 'index'])
    ->name('permissions.index');



Route::get('auth/customers', [CustomerController::class, 'customers'])
    ->name('customers.all');

Route::post('auth/customer/{id}', [CustomerController::class, 'destroy'])
    ->name('customer.destroy');

Route::post('auth/customer', [CustomerController::class, 'store'])
    ->name('customer.post');



Route::get('auth/agents', [AgentController::class, 'agents'])
    ->name('agents.all');

Route::post('auth/agents/{id}', [AgentController::class, 'destroy'])
    ->name('agents.destroy');


Route::post('auth/agent', [AgentController::class, 'store'])
    ->name('agent.post');


Route::get('property/types', [PropertyTypeController::class, 'index'])
    ->name('property.types');

Route::post('property/type', [PropertyTypeController::class, 'store'])
    ->name('property.type');


Route::get('property/units', [UnitTypeController::class, 'index'])
    ->name('property.units');

Route::post('property/unit', [UnitTypeController::class, 'store'])
    ->name('property.unit');




Route::get('property/amenities', [AmenityController::class, 'index'])
    ->name('property.amenities');

Route::post('property/amenity', [AmenityController::class, 'store'])
    ->name('property.amenity');



Route::get('property/utilities', [UtilityController::class, 'index'])
    ->name('property.utilities');

Route::post('property/utility', [UtilityController::class, 'store'])
    ->name('property.utility');


Route::get('project/properties', [PropertyController::class, 'index'])
    ->name('project.properties');


Route::post('project/property', [PropertyController::class, 'store'])
    ->name('project.property');





Route::get('log-out', [LoginController::class, 'logOut'])->name('auth.log_out');

Route::get('user/notifications', [NotificationController::class, 'index'])
    ->name('user-notifications.index');

Route::post('user/notifications/mark-as-read/{id}', [NotificationController::class, 'markAsRead'])
    ->name('user-notifications.mark-as-read');

Route::post('user/notifications/mark-all-as-read', [NotificationController::class, 'markAsReadAll'])
    ->name('user-notifications.mark-all-as-read');

Route::post('user/notifications/mark-as-unread/{id}', [NotificationController::class, 'markAsUnread'])
    ->name('user-notifications.mark-as-unread');

Route::get('user/activity-log', [ActivityLogController::class, 'show'])
    ->name('activity-log.show');

Route::get('user/activities/{user}', [ActivityLogController::class, 'activities'])
    ->name('user.activities')
    ->middleware('can:view_activities');

Route::get('authenticate-user', [AuthenticateUserController::class, 'show'])
    ->name('user.authenticate-user');

Route::post('auth/users/change-settings', [UserUpdateController::class, 'update'])
    ->name('users.change-settings');

Route::post('auth/users/profile-picture', [UserThumbnailController::class, 'store'])
    ->name('users.change-profile-picture');

Route::group(['prefix' => 'auth/users/{user}'], function () {
    Route::post('password/change', [BaseUserPasswordControllerAlias::class, 'update'])
        ->name('users.change-password');
});

Route::get('languages', [LanguageController::class, 'index'])->name('languages.index');

Route::get('custom-table/view/{custom_table}', [CustomTableController::class, 'viewTable'])
    ->name('custom-table-data.view')
    ->middleware('can:view_custom_tables');
