<?php


use App\Http\Controllers\App\Properties\InterfaceController;
use App\Http\Controllers\Patch\Frontend\FrontendController;
use Illuminate\Support\Facades\Route;

Route::group(['middleware' => ['auth', 'authorize']], function () {


    Route::get('customers/list/view', [InterfaceController::class, 'customerInterface'])
        ->name('customers.index');



    Route::get('customers/documents/kyc', [InterfaceController::class, 'kycDocumentView'])
        ->name('customers.kyc');

    Route::get('agents/list/view', [InterfaceController::class, 'agentsInterface'])
        ->name('agents.index');




    Route::get('sales/list/view', [InterfaceController::class, 'leadsInterface'])
        ->name('sales.index');

    Route::get('documents/list/view', [InterfaceController::class, 'projectInterface'])
        ->name('documents.index');


    Route::get('invoices/create/view', [InterfaceController::class, 'invoiceCreateView'])
        ->middleware('can:view_invoices');



    Route::get('titles', [InterfaceController::class, 'titleInterface'])
        ->name('titles.index');


    Route::get('projects/lists/view', [InterfaceController::class, 'directoryInterface'])
        ->name('projects.index');


    Route::get('payments/list/view', [InterfaceController::class, 'paymentInterface'])
        ->name('payments.index');


    Route::get('payments/reserved/list/view', [InterfaceController::class, 'reservedPaymentInterface'])
        ->name('reserved.payments');


    Route::get('agents/leads/offer/letter', [InterfaceController::class, 'offerLetterInterface'])
        ->name('offer.letter');

    Route::get('agents/leads/sale/agreement', [InterfaceController::class, 'saleAgreementInterface'])
        ->name('sale.agreement');

    Route::get('agents/leads/unsuccessful', [InterfaceController::class, 'unsuccessfulLeadsInterface'])
        ->name('leads.unsuccessful');


    Route::get('agents/leads/prospects', [InterfaceController::class, 'listProspectnterface'])
        ->name('leads.prospects');

    Route::get('properties/list/view', [InterfaceController::class, 'propertyInterface'])
        ->name('properties.ui');


    Route::get('companies/list/view', [InterfaceController::class, 'companyInterface'])
        ->name('companies.ui');


    Route::get('agent/leads/view', [InterfaceController::class, 'agentLeadsInterface'])
        ->name('agents.leads');


    Route::get('invoices/list/view', [InterfaceController::class, 'invoiceInterface'])
        ->name('invoices.ui');

    Route::get('properties/{id}/details', [InterfaceController::class, 'propertyDetailsView'])
        ->name('properties.details')->middleware('can:view_property_details');


    Route::get('unit/for/sale/{id}/details', [InterfaceController::class, 'propertySellingDetailsView'])
        ->name('unisale.details');

    Route::get('unit/sold/{id}/details', [InterfaceController::class, 'unitBookingDetailsView'])
        ->name('unisold.details');


    Route::get('unit/lead/offer/letter/{id}/details', [InterfaceController::class, 'offerLetterDetailsView'])
        ->name('unisale.lead');


    Route::get('unit/lead/sale/agreement/{id}/details', [InterfaceController::class, 'saleAgreementDetailsView'])
        ->name('unisale.agreement');






    Route::get('liaisons/{id}/details', [InterfaceController::class, 'agentDetailsView'])
        ->name('liaisons.details');

    Route::get('property-setting', [InterfaceController::class, 'settingInterface'])
        ->name('property.all');


    Route::get('create-property', [InterfaceController::class, 'createProperty'])
        ->name('property.create');

    Route::get('properties/units/view', [InterfaceController::class, 'proprtyUnitInterface'])
        ->name('property.units');


    Route::get('properties/admin/units', [InterfaceController::class, 'adminUnitInterface'])
        ->name('admin.units');

    Route::get('props/units/{id}/details', [InterfaceController::class, 'propertyUnitDetailsView'])
        ->name('props.details')->middleware('can:property_units_view');

    Route::get('properties/units/sold/view', [InterfaceController::class, 'unitBookingView'])
        ->name('property.sold');


    Route::get('rewards/commission/list/view', [InterfaceController::class, 'commissionInterface'])
        ->name('rewards.commission');

    Route::get('rewards/earning/list/view', [InterfaceController::class, 'earningInterface'])
        ->name('rewards.earning');


    Route::get('finance/confirm/offer/letter/view', [InterfaceController::class, 'financeOfferLetterView'])
        ->name('finance.offerletter');




    Route::get('legal/process/offer/letter/view', [InterfaceController::class, 'processOfferLetterView'])
        ->name('legal.offerletter');



    Route::get('finance/confirm/sale/agreement/view', [InterfaceController::class, 'financeSaleAgreementView'])
        ->name('finance.saleagreement');


    Route::get('legal/process/titles/view', [InterfaceController::class, 'completedPaymentsView'])
        ->name('legal.titles');


    Route::get('legal/process/sale/agreement/view', [InterfaceController::class, 'processSaleAgreementView'])
        ->name('legal.saleagreement');

    Route::get('clients/{id}/details', [InterfaceController::class, 'clientDetailsView'])->name('clients.info');



    Route::get('invoices/{id}/details', [FrontendController::class, 'invoiceDetails'])
        ->middleware('can:view_invoices');


    Route::get('client/statement/{id}/details', [InterfaceController::class, 'clientStatementDetailsView'])
        ->middleware('can:client_statement_report_reports');


    Route::get('finance/payments/confirm/view', [InterfaceController::class, 'paymentConfirmView'])
        ->name('payment.confirm');



    Route::get('general-summary', [FrontendController::class, 'generalSummaryView']);
    Route::get('payment-summary', [FrontendController::class, 'paymentSummaryView'])
        ->middleware('can:payment_summary_reports');
    Route::get('client-statement', [FrontendController::class, 'clientStatementView'])
        ->middleware('can:client_statement_report_reports');
    Route::get('invoice-report', [FrontendController::class, 'invoiceReportView'])
        ->middleware('can:invoice_report_reports');
    //Route::get('expense-report', [FrontendController::class, 'expenseReportView']);

    Route::get('recurring/invoice/list/view', [FrontendController::class, 'recurringInvoiceView'])
        ->middleware('can:view_invoices');

});
